/*
 * AquaRoutesList.java
 *
 * Created on 16  2004 ., 12:45
 */

package com.fn.BikersLog;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import javax.swing.AbstractListModel;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;


/**
 *
 * @author  asso
 */
public class AquaRoutesList extends AbstractListModel {
    
    private List routes = new ArrayList();
    private Map allRoutes = new TreeMap();
    private ImageStorage imageStorage;
    
    /** Creates a new instance of AquaRoutesList */
    public AquaRoutesList(ImageStorage is) {
        imageStorage = is;
    }
    
    public AquaRoute get(int index) {
        return (AquaRoute)routes.get(index);
    }
    
    public AquaRoute getById(int id) {
        return (AquaRoute)allRoutes.get(new Integer(id));
    }
    
    public Object getElementAt(int index) {
        return routes.get(index);
    }
    
    public int getSize() {
        return routes.size();
    }
    
    public void add(AquaRoute route) {
        route.setId(getNextId());
        allRoutes.put(new Integer(route.getId()), route);
        if (! route.isDeleted()) {
            routes.add(route);
            fireIntervalAdded(this, routes.size() - 1, routes.size() - 1);
        }
    }
    
    public void change(int index) {
        fireContentsChanged(this, index, index);
    }
    
    protected void load(Element root) {
        if (root == null) return;
        NodeList elements = root.getElementsByTagName("aquaRoute");
        int size = elements.getLength();
        for (int i = 0; i < size; i++) {
            AquaRoute r = new AquaRoute(imageStorage, (Element)elements.item(i));
            if (! r.isDeleted())
                routes.add(r);
            allRoutes.put(new Integer(r.getId()), r);
        }
    }
    
    protected void save(Document document, Element root) {
        Element routes = document.createElement("aquaRoutes");
        root.appendChild(routes);
        
        for (Iterator i = this.routes.iterator(); i.hasNext(); ) {
            AquaRoute r = (AquaRoute)i.next();
            r.save(document, routes);
        }
        
        for (Iterator i = allRoutes.values().iterator(); i.hasNext(); ) {
            AquaRoute r = (AquaRoute)i.next();
            if (r.isDeleted())
                r.save(document, routes);
        }
    }
    
    public void delete(int index) {
        AquaRoute r = get(index);
        r.setDeleted(true);
        routes.remove(index);
        fireIntervalRemoved(this, index, index);
    }
    
    public int getNextId() {
        int maxId = 0;
        for (Iterator i = allRoutes.values().iterator(); i.hasNext(); ) {
            AquaRoute r = (AquaRoute)i.next();
            int id = r.getId();
            if (id > maxId)
                maxId = id;
        }
        return maxId + 1;
    }
    
    public int getIndexOf(AquaRoute route) {
        return routes.indexOf(route);
    }
    
    public void updateAll() {
        fireContentsChanged(this, 0, getSize());
    }
}
