/*
 * BoatsList.java
 *
 * Created on 16  2004 ., 11:19
 */

package com.fn.BikersLog;


import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import javax.swing.AbstractListModel;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;


/**
 *
 * @author  asso
 */
public class BoatsList extends AbstractListModel {
    
    private List boats;
    private Map allBoats;
    private ImageStorage imageStorage;
    
    /** Creates a new instance of BoatsList */
    public BoatsList(ImageStorage is) {
        boats = new ArrayList();
        allBoats = new TreeMap();
        imageStorage = is;
    }
    
    public Boat get(int index) {
        return (Boat)boats.get(index);
    }
    
    public Boat getById(int id) {
        return (Boat)allBoats.get(new Integer(id));
    }
    
    public Object getElementAt(int index) {
        return get(index);
    }
    
    public int getSize() {
        return boats.size();
    }
    
    protected void load(Element root) {
        if (root == null) return;
        NodeList elements = root.getElementsByTagName("boat");
        int size = elements.getLength();
        for (int i = 0; i < size; i++) {
            Boat b = new Boat(imageStorage, (Element)elements.item(i));
            if (! b.isDeleted())
                boats.add(b);
            allBoats.put(new Integer(b.getId()), b);
        }
    }
    
    protected void save(Document document, Element root) {
        Element boats = DOMUtil.addElement(document, root, "boats");
        
        for (Iterator i = this.boats.iterator(); i.hasNext(); )
            ((Boat)i.next()).save(document, boats);
        
        for (Iterator i = allBoats.values().iterator(); i.hasNext(); ) {
            Boat b = (Boat)i.next();
            if (b.isDeleted())
                b.save(document, boats);
        }
    }
    
    public void add(Boat boat) {
        boat.setId(getNextId());
        allBoats.put(new Integer(boat.getId()), boat);
        if (! boat.isDeleted()) {
            boats.add(boat);
            fireIntervalAdded(this, boats.size() - 1, boats.size() - 1);
        }
    }
    
    public void change(int index) {
        fireContentsChanged(this, index, index);
    }
    
    public void delete(int index) {
        Boat b = get(index);
        b.setDeleted(true);
        boats.remove(index);
        fireIntervalRemoved(this, index, index);
    }
    
    public int getNextId() {
        int maxId = 0;
        for (Iterator i = allBoats.values().iterator(); i.hasNext(); ) {
            Boat b = (Boat)i.next();
            int id = b.getId();
            if (id > maxId)
                maxId = id;
        }
        return maxId + 1;
    }
    
    public int getIndexOf(Boat boat) {
        return boats.indexOf(boat);
    }
}
