/*
 * CoursesList.java
 *
 * Created on 27  2003 ., 15:26
 */

package com.fn.BikersLog;


import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import javax.swing.AbstractListModel;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;


/**
 *
 * @author  asso
 */
public class CoursesList extends AbstractListModel {

    private List courses = new ArrayList();
    private Map allCourses = new TreeMap();
    private ImageStorage imageStorage;
    
    /** Creates a new instance of CoursesList */
    public CoursesList(ImageStorage is) {
        imageStorage = is;
    }
    
    public Course get(int index) {
        return (Course)courses.get(index);
    }
    
    public Course getById(int id) {
        return (Course)allCourses.get(new Integer(id));
    }
    
    public Object getElementAt(int index) {
        return courses.get(index);
    }
    
    public int getSize() {
        return courses.size();
    }
    
    public void addCourse(Course course) {
        course.setId(getNextId());
        allCourses.put(new Integer(course.getId()), course);
        if (! course.isDeleted()) {
            courses.add(course);
            fireIntervalAdded(this, courses.size() - 1, courses.size() - 1);
        }
    }
    
    public void changeCourse(int index) {
        fireContentsChanged(this, index, index);
    }
    
    protected void load(Element root) throws Exception {
        if (root == null) return;
        NodeList elements = root.getElementsByTagName("course");
        int size = elements.getLength();
        for (int i = 0; i < size; i++) {
            Course c = new Course(imageStorage, (Element)elements.item(i));
            if (! c.isDeleted())
                courses.add(c);
            allCourses.put(new Integer(c.getId()), c);
        }
    }
    
    protected void save(Document document, Element root) {
        Element courses = document.createElement("courses");
        root.appendChild(courses);
        
        for (Iterator i = this.courses.iterator(); i.hasNext(); ) {
            Course c = (Course)i.next();
            c.save(document, courses);
        }
        
        for (Iterator i = allCourses.values().iterator(); i.hasNext(); ) {
            Course c = (Course)i.next();
            if (c.isDeleted())
                c.save(document, courses);
        }
    }
    
    public void deleteCourse(int index) {
        Course c = get(index);
        c.setDeleted(true);
        courses.remove(index);
        fireIntervalRemoved(this, index, index);
    }
    
    public int getNextId() {
        int maxId = 0;
        for (Iterator i = allCourses.values().iterator(); i.hasNext(); ) {
            Course c = (Course)i.next();
            int id = c.getId();
            if (id > maxId)
                maxId = id;
        }
        return maxId + 1;
    }
    
    public int getIndexOf(Course course) {
        return courses.indexOf(course);
    }
    
    public void updateAll() {
        fireContentsChanged(this, 0, getSize());
    }
}
