/*
 * DOMUtil.java
 *
 * Created on 8  2003 ., 13:04
 */

package com.fn.BikersLog;

/*
 * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistribution in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in
 *   the documentation and/or other materials provided with the
 *   distribution.
 *
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN
 * OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR
 * FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR
 * PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF
 * LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE SOFTWARE,
 * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 *
 * You acknowledge that Software is not designed, licensed or intended
 * for use in the design, construction, operation or maintenance of
 * any nuclear facility.
 */


import java.awt.image.BufferedImage;

import java.io.IOException;
import java.io.File;

import java.text.DateFormat;

import java.util.Date;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.DocumentBuilder;

import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.Source;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.Result;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;

import org.xml.sax.SAXParseException;
import org.xml.sax.SAXException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;


/**
 * Sample Utility class to work with DOM document
 */
public class DOMUtil {
    
    /** Prints the specified node, then prints all of its children. */
    public static void printDOM(Node node) {
        int type = node.getNodeType();
        switch (type) {
            // print the document element
            case Node.DOCUMENT_NODE: {
                System.out.println("<?xml version=\"1.0\" ?>");
                printDOM(((Document)node).getDocumentElement());
                break;
            }
            
            // print element with attributes
            case Node.ELEMENT_NODE: {
                System.out.print("<");
                System.out.print(node.getNodeName());
                NamedNodeMap attrs = node.getAttributes();
                for (int i = 0; i < attrs.getLength(); i++) {
                    Node attr = attrs.item(i);
                    System.out.print(" " + attr.getNodeName().trim() +
                    "=\"" + attr.getNodeValue().trim() +
                    "\"");
                }
                System.out.println(">");
                
                NodeList children = node.getChildNodes();
                if (children != null) {
                    int len = children.getLength();
                    for (int i = 0; i < len; i++)
                        printDOM(children.item(i));
                }
                
                break;
            }
            
            // handle entity reference nodes
            case Node.ENTITY_REFERENCE_NODE: {
                System.out.print("&");
                System.out.print(node.getNodeName().trim());
                System.out.print(";");
                break;
            }
            
            // print cdata sections
            case Node.CDATA_SECTION_NODE: {
                System.out.print("");
                break;
            }
            
            // print text
            case Node.TEXT_NODE: {
                System.out.print(node.getNodeValue().trim());
                break;
            }
            
            // print processing instruction
            case Node.PROCESSING_INSTRUCTION_NODE: {
                System.out.print("");
                break;
            }
        }
        
        if (type == Node.ELEMENT_NODE) {
            System.out.println();
            System.out.print("'");
        }
    }
    
    /**
     * Parse the XML file and create Document
     * @param fileName
     * @return Document
     */
    public static Document parse(java.io.InputStream inputStream) {
        Document document = null;
        // Initiate DocumentBuilderFactory
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        
        // To get a validating parser
        factory.setValidating(false);
        // To get one that understands namespaces
        factory.setNamespaceAware(true);
        
        try {
            // Get DocumentBuilder
            DocumentBuilder builder = factory.newDocumentBuilder();
            // Parse and load into memory the Document
            document = builder.parse(inputStream);
            return document;
            
        } catch (SAXParseException spe) {
            // Error generated by the parser
            System.out.println("\n** Parsing error , line " + spe.getLineNumber()
            + ", uri " + spe.getSystemId());
            System.out.println(" " + spe.getMessage() );
            // Use the contained exception, if any
            Exception x = spe;
            if (spe.getException() != null)
                x = spe.getException();
            x.printStackTrace();
        } catch (SAXException sxe) {
            // Error generated during parsing
            Exception x = sxe;
            if (sxe.getException() != null)
                x = sxe.getException();
            x.printStackTrace();
        } catch (ParserConfigurationException pce) {
            // Parser with specified options can't be built
            pce.printStackTrace();
        } catch (IOException ioe) {
            // I/O error
            ioe.printStackTrace();
        }
        
        return null;
    }
    
    /**
     * This method writes a DOM document to a file
     * @param filename
     * @param document
     */
    public static void writeXmlToFile(java.io.OutputStream stream, Document document) {
        try {
            // Prepare the DOM document for writing
            Source source = new DOMSource(document);
            
            // Prepare the output file
            Result result = new StreamResult(stream);
            
            // Write the DOM document to the file
            // Get Transformer
            Transformer xformer = TransformerFactory.newInstance().newTransformer();
            // Write to a file
            xformer.transform(source, result);
            try { stream.close(); } catch (Exception e) { }
        } catch (TransformerConfigurationException e) {
            System.out.println("TransformerConfigurationException: " + e);
        } catch (TransformerException e) {
            System.out.println("TransformerException: " + e);
        }
    }
    
    /**
     * Count Elements in Document by Tag Name
     * @param tag
     * @param document
     * @return number elements by Tag Name
     */
    public static int countByTagName(String tag, Document document){
        NodeList list = document.getElementsByTagName(tag);
        return list.getLength();
    }
    
    
    public static Document createDocument() {
        Document document = null;
        DocumentBuilder builder = null;
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        try{
            builder = factory.newDocumentBuilder();
            document = builder.newDocument();
        } catch (ParserConfigurationException e) {
            e.printStackTrace();
        }
        return document;
    }
    
    public static Element getTagByName(Element root, String name) {
        NodeList nodeList = root.getElementsByTagName(name);
        if (nodeList.getLength() < 1)
            return null;
        else
            return (Element)nodeList.item(0);
    }
    
    public static String getSubtagData(Element tag, String name, String dflt) {
        StringBuffer sb = new StringBuffer();
        NodeList nodeList = tag.getElementsByTagName(name);
        if (nodeList.getLength() < 1) return dflt;
        Element element = (Element)nodeList.item(0);
        nodeList = element.getChildNodes();
        int len = nodeList.getLength();
        for (int i = 0; i < len; i++) {
            Node node = nodeList.item(i);
            short nodeType = node.getNodeType();
            if (nodeType == Node.TEXT_NODE)
                sb.append(node.getNodeValue());
        }
        return sb.toString();
    }
    
    public static int getSubtagData(Element tag, String name, int dflt) {
        try {
            String s = getSubtagData(tag, name, (String)null);
            if (s == null)
                return dflt;
            return Integer.parseInt(s);
        } catch (Exception e) {
            return dflt;
        }
    }
    
    public static double getSubtagData(Element tag, String name, double dflt) {
        try {
            String s = getSubtagData(tag, name, (String)null);
            if (s == null)
                return dflt;
            return Double.parseDouble(s);
        } catch (Exception e) {
            return dflt;
        }
    }
    
    public static Date getSubtagData(Element tag, String name, Date dflt) {
        try {
            DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
            String s = getSubtagData(tag, name, (String)null);
            if (s == null)
                return dflt;
            if (s.indexOf(' ') > 0) {       // 1.0 date format
                return df.parse(s);
            } else {
                long v = Long.parseLong(s);
                return new Date(v);
            }
        } catch (Exception e) {
            return dflt;
        }
    }
    
    public static boolean getSubtagData(Element tag, String name, boolean dflt) {
        int res = getSubtagData(tag, name, dflt ? 1 : 0);
        return res != 0;
    }
    
    public static Element addElement(Document doc, Element root, String name) {
        Element tag = doc.createElement(name);
        root.appendChild(tag);
        return tag;
    }
    
    public static Element addDataElement(Document doc, Element root, String name, String data) {
        Element tag = doc.createElement(name);
        root.appendChild(tag);
        Text text = doc.createTextNode(data);
        tag.appendChild(text);
        return tag;
    }
    
    public static Element addDataElement(Document doc, Element root, String name, int data) {
        String s = Integer.toString(data);
        return addDataElement(doc, root, name, s);
    }
    
    public static Element addDataElement(Document doc, Element root, String name, double data) {
        String s = Double.toString(data);
        return addDataElement(doc, root, name, s);
    }
    
    public static Element addDataElement(Document doc, Element root, String name, boolean data) {
        return addDataElement(doc, root, name, data ? 1 : 0);
    }
    
    public static Element addDataElement(Document doc, Element root, String name, Date date) {
        //DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        //String s = df.format(date);
        // always save date in new format
        return addDataElement(doc, root, name, Long.toString(date.getTime()));
    }
    
    public static String getAttrib(Element tag, String attrib, String dflt) {
        if (tag == null) return dflt;
        String s = tag.getAttribute(attrib);
        return (s.length() < 1) ? dflt : s;
    }
    
    public static void setAttrib(Element tag, String name, String value) {
        try {
            tag.setAttribute(name, value);
        } catch (Exception e) { }
    }
    
    public static double getAttrib(Element tag, String attrib, double dflt) {
        if (tag == null) return dflt;
        String s = tag.getAttribute(attrib);
        if (s.length() < 1)
            return dflt;
        else {
            try {
                return Double.parseDouble(s);
            } catch (Exception e) {
                return dflt;
            }
        }
    }
    
    public static void setAttrib(Element tag, String name, double value) {
        setAttrib(tag, name, Double.toString(value));
    }
    
    public static int getAttrib(Element tag, String attrib, int dflt) {
        if (tag == null) return dflt;
        String s = tag.getAttribute(attrib);
        if (s.length() < 1)
            return dflt;
        else {
            try {
                return Integer.parseInt(s);
            } catch (Exception e) {
                return dflt;
            }
        }
    }
    
    public static void setAttrib(Element tag, String name, int value) {
        setAttrib(tag, name, Integer.toString(value));
    }
    
    public static boolean getAttrib(Element tag, String attrib, boolean dflt) {
        if (tag == null) return dflt;
        String s = tag.getAttribute(attrib).toLowerCase();
        if (s.length() < 1) 
            return dflt;
        if (s.equals("on") || s.equals("yes") || s.equals("true") || s.equals("rulez"))
            return true;
        else if (s.equals("off") || s.equals("no") || s.equals("false") || s.equals("suxx"))
            return false;
        else
            return dflt;
    }    
    
    public static void setAttrib(Element tag, String name, boolean value) {
        setAttrib(tag, name, value ? "yes" : "no");
    }
}
