/*
 * Document.java
 *
 * Created on 27  2003 ., 12:46
 */

package com.fn.BikersLog;

import java.io.File;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 *
 * @author  asso
 */
public class Log {
    
    private DataFile file;
    private boolean saved = true;
    private CoursesList coursesList;
    private AquaRoutesList aquaRoutesList;
    private BikesList bikesList;
    private BoatsList boatsList;
    private EventsList eventsList = new EventsList();
    private ImageStorage imageStorage;
    private RunRoutesList runRoutesList;
    private SkisList skisList;
    private SkiingRoutesList skiingRoutesList;
    
    /** Creates a new instance of Document */
    public Log() {
        file = new DataFile();
        imageStorage = new ImageStorage(file);
        init();
    }
    
    public Log(File file) throws Exception {
        this.file = new DataFile(file);
        imageStorage = new ImageStorage(this.file);
        init();
        load();
    }

    private void init() {
        coursesList = new CoursesList(imageStorage);
        aquaRoutesList = new AquaRoutesList(imageStorage);
        bikesList = new BikesList(imageStorage);
        boatsList = new BoatsList(imageStorage);
        runRoutesList = new RunRoutesList(imageStorage);
        skisList = new SkisList(imageStorage);
        skiingRoutesList = new SkiingRoutesList(imageStorage);
    }
    
    private void putData() {
        Document document = DOMUtil.createDocument();
        Element root = (Element)document.createElement("BikersLog");
        root.setAttribute("major", "1");
        root.setAttribute("minor", "6");
        document.appendChild(root);
        coursesList.save(document, root);
        aquaRoutesList.save(document, root);
        bikesList.save(document, root);
        boatsList.save(document, root);
        runRoutesList.save(document, root);
        skisList.save(document, root);
        skiingRoutesList.save(document, root);
        eventsList.save(document, root);
        document.getDocumentElement().normalize();
        DOMUtil.writeXmlToFile(file.getResourseOutput("log.xml"), document);
    }
    
    public void saveAs(File f) throws Exception {
        putData();
        file.writeAs(f);
        saved = true;
    }
    
    public void save() throws Exception {
        putData();
        file.write();
        saved = true;
    }
    
    private void load() throws Exception {
        Document document = DOMUtil.parse(file.getResourseInput("log.xml"));
        Element root = document.getDocumentElement();
        if (! root.getNodeName().equals("BikersLog"))
            throw new Exception("Invalid document");
        coursesList.load(DOMUtil.getTagByName(root, "courses"));
        aquaRoutesList.load(DOMUtil.getTagByName(root, "aquaRoutes"));
        bikesList.load(DOMUtil.getTagByName(root, "bikes"));
        boatsList.load(DOMUtil.getTagByName(root, "boats"));
        runRoutesList.load(DOMUtil.getTagByName(root, "runRoutes"));
        skisList.load(DOMUtil.getTagByName(root, "skis"));
        skiingRoutesList.load(DOMUtil.getTagByName(root, "skiingRoutes"));
        eventsList.load(DOMUtil.getTagByName(root, "events"), this);
        saved = true;
    }
    
    public DataFile getFile() {
        return file;
    }
    
    public boolean isSaved() {
        return saved;
    }
    
    public void markAsUnsaved() {
        saved = false;
    }
    
    public CoursesList getCoursesList() {
        return coursesList;
    }
    
    public AquaRoutesList getAquaRoutesList() {
        return aquaRoutesList;
    }
    
    public RunRoutesList getRunRoutesList() {
        return runRoutesList;
    }
    
    public BikesList getBikesList() {
        return bikesList;
    }
    
    public BoatsList getBoatsList() {
        return boatsList;
    }
    
    public EventsList getEventsList() {
        return eventsList;
    }
    
    public ImageStorage getImageStorage() {
        return imageStorage;
    }
    
    public SkisList getSkisList() {
        return skisList;
    }
    
    public SkiingRoutesList getSkiingRoutesList() {
        return skiingRoutesList;
    }
}
