/*
 * MonthlyEventsTableModel.java
 *
 * Created on 23  2004 ., 13:04
 */

package com.fn.BikersLog;


import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import javax.swing.event.ListDataListener;
import javax.swing.table.AbstractTableModel;


/**
 *
 * @author  asso
 */
public class MonthlyEventsTableModel extends AbstractTableModel 
        implements ListDataListener {
    
    private Calendar calendar;
    private EventsList eventsList;
    private int firstDayOfWeek;
    private int startColumn;
    private int daysInMonth;
    private int rows;
    private List dailyEvents;
    private String[] daysOfWeek;
    
    /** Creates a new instance of MonthlyEventsTableModel */
    public MonthlyEventsTableModel(EventsList events) {
        calendar = Calendar.getInstance();
        eventsList = events;
        firstDayOfWeek = calendar.getFirstDayOfWeek();
        dailyEvents = new ArrayList();
        setMonth(new Date());
        setDaysOfWeek();
    }
    
    private void setDaysOfWeek() {
        SimpleDateFormat sdf = new SimpleDateFormat("EEE");
        daysOfWeek = new String[7];
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.DAY_OF_WEEK, firstDayOfWeek);
        for (int i = 0; i < 7; i++) {
            daysOfWeek[i] = sdf.format(cal.getTime());
            cal.add(Calendar.DATE, 1);
        }
    }
    
    public Class getColumnClass(int columnIndex) {
        return EventsInDay.class;
    }
    
    public int getColumnCount() {
        return 7;
    }
    
    public int getRowCount() {
        return rows;
    }

    public String getColumnName(int index) {
        return daysOfWeek[index];
    }
    
    public Object getValueAt(int rowIndex, int columnIndex) {
        return dailyEvents.get(rowIndex * 7 + columnIndex);
    }
    
    private int getMaxDaysInMonth() {
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.add(Calendar.MONTH, 1);
        calendar.add(Calendar.DAY_OF_MONTH, -1);
        return calendar.get(Calendar.DAY_OF_MONTH);
    }
    
    private int getDayOfWeek(int day) {
        calendar.set(Calendar.DAY_OF_MONTH, day);
        return calendar.get(Calendar.DAY_OF_WEEK);
    }
    
    private int getDayOfWeekColumn(int dayOfWeek) {
        int column = dayOfWeek - firstDayOfWeek;
        if (column < 0)
            column += 7;
        return column;
    }
    
    private void populateDailyEvents() {
        int currentYear = calendar.get(Calendar.YEAR);
        int currentMonth = calendar.get(Calendar.MONTH);
        int currentDay = -1;
        EventsInDay currentEvents = null;
        
        Calendar cal = Calendar.getInstance();
        int cnt = eventsList.getSize();
        for (int i = 0; i < cnt; i++) {
            Event e = (Event)eventsList.get(i);
            cal.setTime(e.getStart());
            int eventYear = cal.get(Calendar.YEAR);
            int eventMonth = cal.get(Calendar.MONTH);
            if (eventYear < currentYear)
                break;
            if (eventYear == currentYear) {
                if (eventMonth == currentMonth) {
                    int eventDay = cal.get(Calendar.DAY_OF_MONTH);
                    if (eventDay != currentDay) {
                        currentDay = eventDay;
                        currentEvents = (EventsInDay)dailyEvents.get(
                                currentDay - 1 + startColumn);
                    }
                    if (null != currentEvents)
                        currentEvents.addEvent(e);
                } else
                    if (eventMonth < currentMonth)
                        break;
            }
        }
    }
    
    private void createDailyEvents() {
        dailyEvents.clear();
        for (int i = 0; i < startColumn; i++)
            dailyEvents.add(null);
        calendar.set(Calendar.DAY_OF_MONTH, 1);
        calendar.add(Calendar.DAY_OF_MONTH, -1);
        for (int i = 0; i < daysInMonth; i++) {
            calendar.add(Calendar.DAY_OF_MONTH, 1);
            dailyEvents.add(new EventsInDay(calendar.getTime()));
        }
        while (dailyEvents.size() < rows * 7)
            dailyEvents.add(null);
        populateDailyEvents();
    }
    
    public void setMonth(Date date) {
        calendar.setTime(date);
        daysInMonth = getMaxDaysInMonth();
        int dayOfWeek = getDayOfWeek(1);
        startColumn = getDayOfWeekColumn(dayOfWeek);
        rows = (daysInMonth + startColumn) / 7;
        if (rows * 7 < daysInMonth + startColumn) 
            rows++;
        createDailyEvents();
        fireTableStructureChanged();
        fireTableDataChanged();
    }
    
    public void updateData() {
        createDailyEvents();
        fireTableRowsUpdated(0, rows-1);
    }
    
    public Date getMonth() {
        return calendar.getTime();
    }
    
    public void setEventsList(EventsList list) {
        eventsList = list;
        createDailyEvents();
        fireTableDataChanged();
    }
    
    public void contentsChanged(javax.swing.event.ListDataEvent e) {
        updateData();
    }
    
    public void intervalAdded(javax.swing.event.ListDataEvent e) {
        int idx0 = e.getIndex0();
        int idx1 = e.getIndex1();
        Calendar cal = Calendar.getInstance();
        for (int i = idx0; i <= idx1; i++) {
            Event event = eventsList.get(i);
            cal.setTime(event.getStart());
            if ((cal.get(Calendar.YEAR) == calendar.get(Calendar.YEAR)) &&
                    (cal.get(Calendar.MONTH) == calendar.get(Calendar.MONTH)))
            {
                EventsInDay eid = (EventsInDay)dailyEvents.get(
                        cal.get(Calendar.DATE) - 1 + startColumn);
                eid.addEvent(event);
            }
        }
        fireTableRowsUpdated(0, rows-1);
    }
    
    public void intervalRemoved(javax.swing.event.ListDataEvent e) {
        updateData();
    }
    
    public int getDayColumn(int date) {
        return (date - 1 + startColumn) % 7;
    }
    
    public int getDayRow(int date) {
        return (date - 1 + startColumn) / 7;
    }
    
    public EventsInDay getEventsInDay(int row, int column) {
        return (EventsInDay)dailyEvents.get(row * 7 + column);
    }
    
    public Date getDate(int row, int column) {
        if ((0 > row) || (0 > column))
            return null;
        int day = row * 7 + column - startColumn + 1;
        if ((day < 1) || (day > daysInMonth))
            return null;
        calendar.set(Calendar.DAY_OF_MONTH, day);
        return calendar.getTime();
    }
}
