/*
 * RideWindow.java
 *
 * Created on 13  2003 ., 12:29
 */

package com.fn.BikersLog;


import java.text.NumberFormat;
import java.text.DateFormat;
import java.util.Date;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JOptionPane;


/**
 *
 * @author  asso
 */
public class RideWindow extends javax.swing.JDialog {
    
    private Log log;
    private RideEvent rideEvent;
    private boolean okPressed = false;
    private DateFormat dateFormat;
    
    /** Creates new form RideWindow */
    public RideWindow(java.awt.Frame parent, Log log, RideEvent re, boolean editing) {
        super(parent, true);
        if (editing)
            setTitle(I18n.getMsg("rideForm.editTitle"));
        else
            setTitle(I18n.getMsg("rideForm.newTitle"));
        this.log = log;
        rideEvent = re;
        dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        dateFormat.setLenient(false);
        initComponents();
        fillDicts();
        setValues();
        Utils.centerWindow(this, parent);
    }
    
    private void fillDicts() {
        String yesNo[] = new String[2];
        yesNo[0] = I18n.getMsg("generic.no");
        yesNo[1] = I18n.getMsg("generic.yes");        
        loopedCombo.setModel(new DefaultComboBoxModel(yesNo));
        
        String items[] = new String[4];
        for (int i = 0; i < items.length; i++)
            items[i] = I18n.getMsg("rideType." + Integer.toString(i + 1));
        rideTypeCombo.setModel(new DefaultComboBoxModel(items));
        
        items = new String[5];
        for (int i = 0; i < items.length; i++)
            items[i] = I18n.getMsg("windDir." + Integer.toString(i + 1));
        windDirCombo.setModel(new DefaultComboBoxModel(items));
        
        items = new String[13];
        for (int i = 0; i < items.length; i++)
            items[i] = I18n.getMsg("windSpeed." + Integer.toString(i));
        windSpeedCombo.setModel(new DefaultComboBoxModel(items));
    }
    
    private void setValues() {
        Bike bike = rideEvent.getBike();
        if (bike == null)
            bikeCombo.setSelectedIndex(0);
        else {
            if (bike.isDeleted()) {
                ((ComboListAdapter)bikeCombo.getModel()).setAddonItem(bike);
                bikeCombo.setSelectedIndex(0);
            } else
                bikeCombo.setSelectedIndex(log.getBikesList().getIndexOf(bike));
        }
        Course course = rideEvent.getCourse();
        if (course == null)
            courseCombo.setSelectedIndex(0);
        else
            if (course.isDeleted()) {
                ((ComboListAdapter)courseCombo.getModel()).setAddonItem(course);
                courseCombo.setSelectedIndex(0);
            } else
                courseCombo.setSelectedIndex(log.getCoursesList().getIndexOf(course));
        distanceTextField.setText(Utils.doubleToStr(Units.
                fromStdBDist(rideEvent.getDistance())));
        loopedCombo.setSelectedIndex(rideEvent.isLooped() ? 1 : 0);
        rideTypeCombo.setSelectedIndex(rideEvent.getRideType() - 1);
        windDirCombo.setSelectedIndex(rideEvent.getWindDirection() - 1);
        windSpeedCombo.setSelectedIndex(rideEvent.getWindSpeed());
        startCalendar.setDate(rideEvent.getStart());
        startTime.setTime(rideEvent.getStart());
        finishCalendar.setDate(rideEvent.getFinish());
        finishTime.setTime(rideEvent.getFinish());
        elapsedTextField.setText(Utils.intervalToTime(rideEvent.getElapsed()));
        temperatureTextField.setText(Integer.toString(rideEvent.getTemperature()));
        speedTextField.setText(Utils.doubleToStr(Units.
                fromStdSpeed(rideEvent.getAvgSpeed())));
        maxSpeedTextField.setText(Utils.doubleToStr(Units.
                fromStdSpeed(rideEvent.getMaxSpeed())));
        hrTextField.setText(Integer.toString(rideEvent.getHeartRate()));
        notesTextArea.setText(rideEvent.getNotes());
        weightTextField.setText(Utils.doubleToStr(
                Units.fromStdWeight(rideEvent.getWeight())));
        cadenceTextField.setText(Utils.doubleToStr(rideEvent.getCadence()));
        caloriesTextField.setText(Utils.doubleToStr(rideEvent.getCalories()));
        wattageTextField.setText(Utils.doubleToStr(rideEvent.getWattage()));
    }
    
    private int getInterval(String text, String exceptionKey) throws Exception {
        int interval;
        try {
            interval = Utils.timetoInterval(text);
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
        if (interval < 0)
            throw new Exception(I18n.getMsg(exceptionKey));
        else
            return interval;
    }
    
    private void getValues() throws Exception {
        double distance = Utils.parseDouble(distanceTextField.getText(), 
                    "rideForm.invalidDistance");
        int elapsed = getInterval(elapsedTextField.getText(), 
                "rideForm.invalidInterval");
        int temperature = Utils.parseInt(temperatureTextField.getText(), 
                "rideForm.invalidTemperature");
        double avgSpeed = Utils.parseDouble(speedTextField.getText(), 
                    "rideForm.invalidSpeed");
        double maxSpeed = Utils.parseDouble(maxSpeedTextField.getText(), 
                    "rideForm.invalidMaxSpeed");
        int heartRate = Utils.parseInt(hrTextField.getText(), 
                    "rideForm.invalidHR");
        double weight = Utils.parseDouble(weightTextField.getText(), 
                    "generic.invalidWeight");
        double calories = Utils.parseDouble(caloriesTextField.getText(), 
                    "rideForm.invalidCalories");
        double wattage = Utils.parseDouble(wattageTextField.getText(), 
                    "rideForm.invalidWattage");
        double cadence = Utils.parseDouble(cadenceTextField.getText(), 
                    "rideForm.invalidCadence");
        
        rideEvent.setBike(log.getBikesList().get(bikeCombo.getSelectedIndex()));
        rideEvent.setCourse(log.getCoursesList().get(courseCombo.getSelectedIndex()));
        rideEvent.setDistance(Units.toStdBDist(distance));
        rideEvent.setLooped(loopedCombo.getSelectedIndex() == 1);
        rideEvent.setRideType(rideTypeCombo.getSelectedIndex() + 1);
        rideEvent.setWindDirection(windDirCombo.getSelectedIndex() + 1);
        rideEvent.setWindSpeed(windSpeedCombo.getSelectedIndex());
        rideEvent.setStart(Utils.calendarToDateTime(startCalendar, startTime));
        rideEvent.setFinish(Utils.calendarToDateTime(finishCalendar, finishTime));
        rideEvent.setElapsed(elapsed);
        rideEvent.setTemperature(temperature);
        rideEvent.setAvgSpeed(Units.toStdSpeed(avgSpeed));
        rideEvent.setMaxSpeed(Units.toStdSpeed(maxSpeed));
        rideEvent.setHeartRate(heartRate);
        rideEvent.setNotes(notesTextArea.getText());
        rideEvent.setWeight(Units.toStdWeight(weight));
        rideEvent.setCalories(calories);
        rideEvent.setWattage(wattage);
        rideEvent.setCadence(cadence);
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        java.awt.GridBagConstraints gridBagConstraints;

        jPanel1 = new javax.swing.JPanel();
        okBtn = new javax.swing.JButton();
        cancelBtn = new javax.swing.JButton();
        jPanel6 = new javax.swing.JPanel();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jPanel2 = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        courseCombo = new javax.swing.JComboBox();
        routeBtn = new javax.swing.JButton();
        jLabel12 = new javax.swing.JLabel();
        loopedCombo = new javax.swing.JComboBox();
        jLabel2 = new javax.swing.JLabel();
        bikeCombo = new javax.swing.JComboBox();
        jLabel8 = new javax.swing.JLabel();
        rideTypeCombo = new javax.swing.JComboBox();
        bikeBtn = new javax.swing.JButton();
        jPanel5 = new javax.swing.JPanel();
        jLabel5 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        elapsedTextField = new javax.swing.JTextField();
        calcElapsedTimeBtn = new javax.swing.JButton();
        startCalendar = new org.rapla.components.calendar.RaplaCalendar();
        startTime = new org.rapla.components.calendar.RaplaTime();
        finishCalendar = new org.rapla.components.calendar.RaplaCalendar();
        finishTime = new org.rapla.components.calendar.RaplaTime();
        jPanel3 = new javax.swing.JPanel();
        jLabel10 = new javax.swing.JLabel();
        windDirCombo = new javax.swing.JComboBox();
        jLabel11 = new javax.swing.JLabel();
        jLabel13 = new javax.swing.JLabel();
        temperatureTextField = new javax.swing.JTextField();
        windSpeedCombo = new javax.swing.JComboBox();
        jPanel4 = new javax.swing.JPanel();
        jLabel3 = new javax.swing.JLabel();
        distanceTextField = new javax.swing.JTextField();
        jLabel4 = new javax.swing.JLabel();
        speedTextField = new javax.swing.JTextField();
        jLabel9 = new javax.swing.JLabel();
        hrTextField = new javax.swing.JTextField();
        calcAvgSpeedBtn = new javax.swing.JButton();
        getDistanceBtn = new javax.swing.JButton();
        jLabel14 = new javax.swing.JLabel();
        maxSpeedTextField = new javax.swing.JTextField();
        jLabel15 = new javax.swing.JLabel();
        wattageTextField = new javax.swing.JTextField();
        jLabel16 = new javax.swing.JLabel();
        cadenceTextField = new javax.swing.JTextField();
        jLabel17 = new javax.swing.JLabel();
        weightTextField = new javax.swing.JTextField();
        jLabel18 = new javax.swing.JLabel();
        caloriesTextField = new javax.swing.JTextField();
        calcCaloriesBtn = new javax.swing.JButton();
        jLabel19 = new javax.swing.JLabel();
        jLabel20 = new javax.swing.JLabel();
        jLabel21 = new javax.swing.JLabel();
        jLabel22 = new javax.swing.JLabel();
        jPanel7 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        notesTextArea = new javax.swing.JTextArea();

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });

        jPanel1.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.CENTER, 8, 8));

        okBtn.setText(I18n.getMsg("generic.ok"));
        okBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okBtnActionPerformed(evt);
            }
        });

        jPanel1.add(okBtn);

        cancelBtn.setText(I18n.getMsg("generic.cancel"));
        cancelBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelBtnActionPerformed(evt);
            }
        });

        jPanel1.add(cancelBtn);

        getContentPane().add(jPanel1, java.awt.BorderLayout.SOUTH);

        jPanel6.setLayout(new javax.swing.BoxLayout(jPanel6, javax.swing.BoxLayout.X_AXIS));

        jPanel6.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 0, 8)));
        jPanel2.setLayout(new java.awt.GridBagLayout());

        jPanel2.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel1.setLabelFor(courseCombo);
        jLabel1.setText(I18n.getMsg("rideForm.ride.course"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel2.add(jLabel1, gridBagConstraints);

        courseCombo.setModel(new ComboListAdapter(log.getCoursesList()));
        courseCombo.setPreferredSize(new java.awt.Dimension(220, 24));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel2.add(courseCombo, gridBagConstraints);

        routeBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/History16.gif")));
        routeBtn.setToolTipText(I18n.getMsg("rideForm.ride.viewRoute"));
        routeBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        routeBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        routeBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                routeBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 4, 0);
        jPanel2.add(routeBtn, gridBagConstraints);

        jLabel12.setLabelFor(loopedCombo);
        jLabel12.setText(I18n.getMsg("rideForm.ride.looped"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel12, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(loopedCombo, gridBagConstraints);

        jLabel2.setLabelFor(bikeCombo);
        jLabel2.setText(I18n.getMsg("rideForm.ride.bike"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel2, gridBagConstraints);

        bikeCombo.setModel(new ComboListAdapter(log.getBikesList()));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(bikeCombo, gridBagConstraints);

        jLabel8.setLabelFor(rideTypeCombo);
        jLabel8.setText(I18n.getMsg("rideForm.ride.rideType"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel2.add(jLabel8, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel2.add(rideTypeCombo, gridBagConstraints);

        bikeBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/History16.gif")));
        bikeBtn.setToolTipText(I18n.getMsg("rideForm.ride.viewBike"));
        bikeBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        bikeBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        bikeBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                bikeBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(4, 8, 4, 0);
        jPanel2.add(bikeBtn, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.ride"), jPanel2);

        jPanel5.setLayout(new java.awt.GridBagLayout());

        jPanel5.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jPanel5.setPreferredSize(new java.awt.Dimension(179, 97));
        jLabel5.setText(I18n.getMsg("rideForm.timing.start"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel5.add(jLabel5, gridBagConstraints);

        jLabel6.setText(I18n.getMsg("rideForm.timing.finish"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel5.add(jLabel6, gridBagConstraints);

        jLabel7.setLabelFor(elapsedTextField);
        jLabel7.setText(I18n.getMsg("rideForm.timing.elapsed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel5.add(jLabel7, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 2.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel5.add(elapsedTextField, gridBagConstraints);

        calcElapsedTimeBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcElapsedTimeBtn.setToolTipText(I18n.getMsg("rideForm.timing.calcLength"));
        calcElapsedTimeBtn.setAlignmentX(0.5F);
        calcElapsedTimeBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcElapsedTimeBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcElapsedTimeBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcElapsedTimeBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel5.add(calcElapsedTimeBtn, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 4);
        jPanel5.add(startCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 4);
        jPanel5.add(startTime, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel5.add(finishCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
        gridBagConstraints.weightx = 0.5;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel5.add(finishTime, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.timing"), jPanel5);

        jPanel3.setLayout(new java.awt.GridBagLayout());

        jPanel3.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel10.setLabelFor(windDirCombo);
        jLabel10.setText(I18n.getMsg("rideForm.weather.windDir"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel3.add(jLabel10, gridBagConstraints);

        windDirCombo.setPreferredSize(new java.awt.Dimension(200, 24));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel3.add(windDirCombo, gridBagConstraints);

        jLabel11.setText(I18n.getMsg("rideForm.weather.windSpeed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel3.add(jLabel11, gridBagConstraints);

        jLabel13.setLabelFor(temperatureTextField);
        jLabel13.setText(I18n.getMsg("rideForm.weather.temperature"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel3.add(jLabel13, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel3.add(temperatureTextField, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel3.add(windSpeedCombo, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.weather"), jPanel3);

        jPanel4.setLayout(new java.awt.GridBagLayout());

        jPanel4.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel3.setLabelFor(distanceTextField);
        jLabel3.setText(I18n.getMsg("rideForm.results.distance"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel3, gridBagConstraints);

        distanceTextField.setPreferredSize(new java.awt.Dimension(150, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel4.add(distanceTextField, gridBagConstraints);

        jLabel4.setLabelFor(speedTextField);
        jLabel4.setText(I18n.getMsg("rideForm.results.speed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel4, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(speedTextField, gridBagConstraints);

        jLabel9.setLabelFor(hrTextField);
        jLabel9.setText(I18n.getMsg("rideForm.results.hr"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel9, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.weightx = 1.0;
        jPanel4.add(hrTextField, gridBagConstraints);

        calcAvgSpeedBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcAvgSpeedBtn.setToolTipText(I18n.getMsg("rideForm.results.calcSpeed"));
        calcAvgSpeedBtn.setAlignmentX(0.5F);
        calcAvgSpeedBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcAvgSpeedBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcAvgSpeedBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcAvgSpeedBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(calcAvgSpeedBtn, gridBagConstraints);

        getDistanceBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        getDistanceBtn.setToolTipText(I18n.getMsg("rideForm.results.getDistance"));
        getDistanceBtn.setAlignmentX(0.5F);
        getDistanceBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        getDistanceBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        getDistanceBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                getDistanceBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(getDistanceBtn, gridBagConstraints);

        jLabel14.setText(I18n.getMsg("rideForm.results.maxSpeed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel14, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(maxSpeedTextField, gridBagConstraints);

        jLabel15.setText(I18n.getMsg("rideForm.results.wattage"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel15, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(wattageTextField, gridBagConstraints);

        jLabel16.setText(I18n.getMsg("rideForm.results.cadence"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel16, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(cadenceTextField, gridBagConstraints);

        jLabel17.setText(I18n.getMsg("rideForm.results.weight"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel17, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(weightTextField, gridBagConstraints);

        jLabel18.setText(I18n.getMsg("rideForm.results.calories"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel18, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel4.add(caloriesTextField, gridBagConstraints);

        calcCaloriesBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcCaloriesBtn.setToolTipText(I18n.getMsg("rideForm.results.calcCalories"));
        calcCaloriesBtn.setAlignmentX(0.5F);
        calcCaloriesBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcCaloriesBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcCaloriesBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcCaloriesBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(calcCaloriesBtn, gridBagConstraints);

        jLabel19.setText(Units.getBDist().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel19, gridBagConstraints);

        jLabel20.setText(Units.getSpeed().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel20, gridBagConstraints);

        jLabel21.setText(Units.getSpeed().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel21, gridBagConstraints);

        jLabel22.setText(Units.getWeight().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 8, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel22, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.results"), jPanel4);

        jPanel7.setLayout(new java.awt.BorderLayout());

        jPanel7.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jScrollPane1.setPreferredSize(new java.awt.Dimension(380, 200));
        notesTextArea.setLineWrap(true);
        notesTextArea.setWrapStyleWord(true);
        jScrollPane1.setViewportView(notesTextArea);

        jPanel7.add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.notes"), jPanel7);

        jPanel6.add(jTabbedPane1);

        getContentPane().add(jPanel6, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents

    private void bikeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bikeBtnActionPerformed
        Bike bike = log.getBikesList().get(bikeCombo.getSelectedIndex());
        BikeWindow.editBike(this, bike);
    }//GEN-LAST:event_bikeBtnActionPerformed

    private void routeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_routeBtnActionPerformed
        Course route = log.getCoursesList().get(courseCombo.getSelectedIndex());
        CourseWindow.editCourse(this, route);
    }//GEN-LAST:event_routeBtnActionPerformed

    private double getAvgSpeed() throws Exception {
        String s = speedTextField.getText();
        double v = Utils.parseDouble(s, "rideForm.invalidSpeed");
        double avgSpeed = Units.toStdBDist(v);
        if (0.0 == avgSpeed)
            throw new Exception(I18n.getMsg("rideForm.invalidSpeed"));
        return avgSpeed;
    }
    
    private double getTotalWeight() throws Exception {
        double v = Utils.parseDouble(weightTextField.getText(), 
            "generic.invalidWeight");
        double weight = Units.toStdWeight(v);
        if (0.0 >= weight)
            throw new Exception(I18n.getMsg("generic.invalidWeight"));
        Bike bike = log.getBikesList().get(bikeCombo.getSelectedIndex());
        weight += bike.getWeight();
        return weight;
    }
    
    private double getElapsedMinutes() throws Exception {
        double elapsed = getInterval(elapsedTextField.getText(), 
            "rideForm.invalidInterval");
        if (0.0 >= elapsed)
            throw new Exception(I18n.getMsg("rideForm.invalidInterval"));
        return elapsed / 60.0;
    }
    
    private double getWindSpeed() {
        return Wind.bofortToKmh(windSpeedCombo.getSelectedIndex());
    }
    
    private double magicFormula(double speed, double weight) {
        return (8.79618 * Math.pow(10, -6) * Math.pow(speed, 3) -
              1.46998 * Math.pow(10, -4) * Math.pow(speed, 2) +
              0.00359 * speed + 0.00556) * weight;
    }
    
    private boolean isAeroPos() {
        Bike bike = log.getBikesList().get(bikeCombo.getSelectedIndex());
        int type = bike.getType();
        return (2 == type) || (4 == type) || (8 == type);
    }
    
    private void calcCaloriesBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcCaloriesBtnActionPerformed
        try {
            double avgSpeed = getAvgSpeed() / 1.609;
            double weight = getTotalWeight() / 0.45359237;
            Course route = log.getCoursesList().get(courseCombo.getSelectedIndex());
            double climbing = route.getHeightsProfile().getClimbPercents();
            boolean looped = loopedCombo.getSelectedIndex() == 1;
            double elevation = route.getHeightsProfile().getElevation();
            double elapsed = getElapsedMinutes();
            double windSpeed = getWindSpeed() / 1.609;
            int windDir = windDirCombo.getSelectedIndex();
        
            double base = magicFormula(avgSpeed, weight);
            double modBase = (base - (weight - 154.0) / 200.0 * base);
            double terrainAdj = climbing / 1000.0 * modBase;
            if (! looped) {
                terrainAdj = terrainAdj + weight * elevation * 0.0014 / elapsed;
                modBase += terrainAdj;
                
                if (0 == windDir) {
                    double speed = avgSpeed + windSpeed / 2.0;
                    modBase = modBase + (magicFormula(speed, weight) - base);
                } else if (4 == windDir) {
                    double speed = avgSpeed - windSpeed / 2.0;
                    modBase = modBase + (magicFormula(speed, weight) - base);
                } else if (1 == windDir) {
                    double speed = avgSpeed + windSpeed / 2.0;
                    modBase = modBase + 0.7 * (magicFormula(speed, weight) - base);
                } else if (3 == windDir) {
                    double speed = avgSpeed - windSpeed / 2.0;
                    modBase = modBase + 0.7 * (magicFormula(speed, weight) - base);
                }
            }
            if ((15.0 < avgSpeed) && (! isAeroPos()))
                modBase = (modBase + (-0.66893 + 0.0467 * avgSpeed) * modBase);
            //modBase = (modBase - (drafting / 100.0) * (avgSpeed / 100.0));
            
            double calories = modBase * elapsed;
            caloriesTextField.setText(Utils.doubleToStr(calories));
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, e.getMessage(),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
        }
    }//GEN-LAST:event_calcCaloriesBtnActionPerformed

    private void getDistanceBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_getDistanceBtnActionPerformed
        Course course = log.getCoursesList().get(courseCombo.getSelectedIndex());
        if (course != null)
            distanceTextField.setText(Utils.doubleToStr(Units.fromStdBDist(course.getLength())));
    }//GEN-LAST:event_getDistanceBtnActionPerformed

    private void calcAvgSpeedBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcAvgSpeedBtnActionPerformed
        double interval = Utils.timetoInterval(elapsedTextField.getText()) / 3600.0;
        if (interval <= 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidInterval"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        double distance;
        try {
            distance = Units.toStdBDist(NumberFormat.
                    getInstance().parse(distanceTextField.getText()).doubleValue());
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidDistance"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        speedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(distance / interval)));
    }//GEN-LAST:event_calcAvgSpeedBtnActionPerformed

    private void calcElapsedTimeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcElapsedTimeBtnActionPerformed
        Date start = Utils.calendarToDateTime(startCalendar, startTime);
        Date finish = Utils.calendarToDateTime(finishCalendar, finishTime);
        int interval = (int)((finish.getTime() - start.getTime()) / 1000);
        if (interval < 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidStartFinish"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        elapsedTextField.setText(Utils.intervalToTime(interval));
    }//GEN-LAST:event_calcElapsedTimeBtnActionPerformed

    private void okBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okBtnActionPerformed
        try {
            getValues();
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, e.getMessage(),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        okPressed = true;
        setVisible(false);
    }//GEN-LAST:event_okBtnActionPerformed

    private void cancelBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelBtnActionPerformed
        okPressed = false;
        setVisible(false);
    }//GEN-LAST:event_cancelBtnActionPerformed
    
    /** Closes the dialog */
    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        setVisible(false);
    }//GEN-LAST:event_closeDialog
    
    public static RideEvent addRide(java.awt.Frame owner, Log log, Date start) {
        RideEvent event = new RideEvent();
        event.setStart(start);
        event.setFinish(start);
        RideWindow rw = new RideWindow(owner, log, event, false);
        rw.setVisible(true);
        rw.dispose();
        return rw.okPressed ? event : null;
    }
    
    public static boolean editRide(java.awt.Frame owner, RideEvent event, Log log) {
        RideWindow rw = new RideWindow(owner, log, event, true);
        rw.setVisible(true);
        rw.dispose();
        return rw.okPressed;
    }
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton bikeBtn;
    private javax.swing.JComboBox bikeCombo;
    private javax.swing.JTextField cadenceTextField;
    private javax.swing.JButton calcAvgSpeedBtn;
    private javax.swing.JButton calcCaloriesBtn;
    private javax.swing.JButton calcElapsedTimeBtn;
    private javax.swing.JTextField caloriesTextField;
    private javax.swing.JButton cancelBtn;
    private javax.swing.JComboBox courseCombo;
    private javax.swing.JTextField distanceTextField;
    private javax.swing.JTextField elapsedTextField;
    private org.rapla.components.calendar.RaplaCalendar finishCalendar;
    private org.rapla.components.calendar.RaplaTime finishTime;
    private javax.swing.JButton getDistanceBtn;
    private javax.swing.JTextField hrTextField;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel19;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel20;
    private javax.swing.JLabel jLabel21;
    private javax.swing.JLabel jLabel22;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JComboBox loopedCombo;
    private javax.swing.JTextField maxSpeedTextField;
    private javax.swing.JTextArea notesTextArea;
    private javax.swing.JButton okBtn;
    private javax.swing.JComboBox rideTypeCombo;
    private javax.swing.JButton routeBtn;
    private javax.swing.JTextField speedTextField;
    private org.rapla.components.calendar.RaplaCalendar startCalendar;
    private org.rapla.components.calendar.RaplaTime startTime;
    private javax.swing.JTextField temperatureTextField;
    private javax.swing.JTextField wattageTextField;
    private javax.swing.JTextField weightTextField;
    private javax.swing.JComboBox windDirCombo;
    private javax.swing.JComboBox windSpeedCombo;
    // End of variables declaration//GEN-END:variables
    
}
