/*
 * TrainEvent.java
 *
 * Created on 12  2003 ., 21:49
 */

package com.fn.BikersLog;


import java.text.DateFormat;
import java.util.Date;
import javax.swing.ImageIcon;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;


/**
 *
 * @author  asso
 */
public class RowingEvent extends Event {
    
    private Boat boat = null;
    private AquaRoute route = null;
    private double distance;
    private int currentDirection = 1;
    private int effort = 1;
    private Date finish = new Date();
    private int elapsed;
    private int windDirection = 1;
    private int windSpeed;
    private int temperature;
    private double avgSpeed;
    private double maxSpeed;
    private int heartRate;
    private String notes;
    private static String rowingType = I18n.getMsg("rowing.type");
    private static ImageIcon icon = null;
    private double wattage;
    private double weight;
    private double calories;
    
    /** Creates a new instance of TrainEvent */
    public RowingEvent() {
    }
    
    public RowingEvent(Element row, Log log) {
        boat = log.getBoatsList().getById(DOMUtil.getSubtagData(row, "boat", 1));
        boat.addRef();
        route = log.getAquaRoutesList().getById(DOMUtil.getSubtagData(row, "route", 1));
        route.addRef();
        distance = DOMUtil.getSubtagData(row, "distance", 0.0);
        currentDirection = DOMUtil.getSubtagData(row, "currentDirection", 1);
        effort = DOMUtil.getSubtagData(row, "effort", 1);
        setStart(DOMUtil.getSubtagData(row, "start", new Date()));
        finish = DOMUtil.getSubtagData(row, "finish", new Date());
        elapsed = DOMUtil.getSubtagData(row, "elapsed", 0);
        windDirection = DOMUtil.getSubtagData(row, "windDirection", 1);
        windSpeed = DOMUtil.getSubtagData(row, "windSpeed", 0);
        temperature = DOMUtil.getSubtagData(row, "temperature", 0);
        avgSpeed = DOMUtil.getSubtagData(row, "avgSpeed", 0.0);
        maxSpeed = DOMUtil.getSubtagData(row, "maxSpeed", 0.0);
        heartRate = DOMUtil.getSubtagData(row, "heartRate", 0);
        notes = DOMUtil.getSubtagData(row, "notes", "");
        wattage = DOMUtil.getSubtagData(row, "wattage", 0.0);
        weight = DOMUtil.getSubtagData(row, "weight", 0.0);
        calories = DOMUtil.getSubtagData(row, "calories", 0.0);
    }
    
    public void setRoute(AquaRoute r) {
        if (route != null)
            route.delRef();
        if (r != null)
            r.addRef();
        route = r;
    }
    
    public AquaRoute getRoute() {
        return route;
    }
    
    public void setBoat(Boat b) {
        if (boat != null)
            boat.delRef();
        if (b != null)
            b.addRef();
        boat = b;
    }
    
    public Boat getBoat() {
        return boat;
    }
    
    public double getDistance() {
        return distance;
    }
    
    public void setDistance(double distance) {
        this.distance = distance;
    }
    
    public int getCurrentDirection() {
        return currentDirection;
    }
    
    public void setCurrentDirection(int cd) {
        currentDirection = cd;
    }
    
    public int getEffort() {
        return effort;
    }
    
    public void setEffort(int v) {
        effort = v;
    }
    
    public java.util.Date getFinish() {
        return finish;
    }
    
    public void setFinish(java.util.Date finish) {
        this.finish = finish;
    }
    
    public int getElapsed() {
        return elapsed;
    }
    
    public void setElapsed(int elapsed) {
        this.elapsed = elapsed;
    }
    
    public int getWindDirection() {
        return windDirection;
    }
    
    public void setWindDirection(int windDirection) {
        this.windDirection = windDirection;
    }
    
    public int getWindSpeed() {
        return windSpeed;
    }
    
    public void setWindSpeed(int windSpeed) {
        this.windSpeed = windSpeed;
    }
    
    public int getTemperature() {
        return temperature;
    }
    
    public void setTemperature(int temperature) {
        this.temperature = temperature;
    }
    
    public double getAvgSpeed() {
        return avgSpeed;
    }
    
    public void setAvgSpeed(double avgSpeed) {
        this.avgSpeed = avgSpeed;
    }
    
    public double getMaxSpeed() {
        return maxSpeed;
    }
    
    public void setMaxSpeed(double maxSpeed) {
        this.maxSpeed = maxSpeed;
    }
    
    public int getHeartRate() {
        return heartRate;
    }
    
    public void setHeartRate(int heartRate) {
        this.heartRate = heartRate;
    }
    
    public java.lang.String getNotes() {
        return notes;
    }
    
    public void setNotes(java.lang.String notes) {
        this.notes = notes;
    }
    
    public String toString() {
        DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        StringBuffer sb = new StringBuffer();
        sb.append(df.format(getStart())).append(' ').append(rowingType);
        sb.append(' ').append(Utils.intervalToTime(elapsed)).append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdBDist(distance)));
        sb.append(Units.getBDist().getShortName());
        sb.append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdSpeed(avgSpeed)));
        sb.append(Units.getSpeed().getShortName());
        return sb.toString();
    }
    
    public void save(Document document, Element root) {
        Element ride = DOMUtil.addElement(document, root, "event");
        DOMUtil.addDataElement(document, ride, "type", "rowing");
        DOMUtil.addDataElement(document, ride, "start", getStart());
        DOMUtil.addDataElement(document, ride, "finish", finish);
        DOMUtil.addDataElement(document, ride, "boat", boat.getId());
        DOMUtil.addDataElement(document, ride, "route", route.getId());
        DOMUtil.addDataElement(document, ride, "distance", distance);
        DOMUtil.addDataElement(document, ride, "currentDirection", currentDirection);
        DOMUtil.addDataElement(document, ride, "effort", effort);
        DOMUtil.addDataElement(document, ride, "elapsed", elapsed);
        DOMUtil.addDataElement(document, ride, "windDirection", windDirection);
        DOMUtil.addDataElement(document, ride, "windSpeed", windSpeed);
        DOMUtil.addDataElement(document, ride, "temperature", temperature);
        DOMUtil.addDataElement(document, ride, "avgSpeed", avgSpeed);
        DOMUtil.addDataElement(document, ride, "maxSpeed", maxSpeed);
        DOMUtil.addDataElement(document, ride, "heartRate", heartRate);
        DOMUtil.addDataElement(document, ride, "notes", notes);
        DOMUtil.addDataElement(document, ride, "wattage", wattage);
        DOMUtil.addDataElement(document, ride, "weight", weight);
        DOMUtil.addDataElement(document, ride, "calories", calories);
    }    
    
    public void onRemove() {
        boat.delRef();
        route.delRef();
    }
    
    public ImageIcon getIcon() {
        if (null == icon)
            icon = new ImageIcon(getClass().getResource("/com/fn/BikersLog/img/rowing.png"));
        return icon;
    }
    
    public Object getColumnData(int column) {
        switch (column) {
            case Event.COLUMN_AVG_SPEED:
                return Utils.doubleToStr(Units.fromStdSpeed(avgSpeed));
            case Event.COLUMN_DISTANCE:
                return Utils.doubleToStr(Units.fromStdBDist(distance));
            case Event.COLUMN_EFFORT:
                return new Integer(effort);
            case Event.COLUMN_ELAPSED:
                return Utils.intervalToTime(elapsed);
            case Event.COLUMN_EQUIPMENT:
                return boat.getName();
            case Event.COLUMN_FINISH:
                return finish;
            case Event.COLUMN_HEART_RATE:
                return new Integer(heartRate);
            case Event.COLUMN_MAX_SPEED:
                return Utils.doubleToStr(Units.fromStdSpeed(maxSpeed));
            case Event.COLUMN_NOTES:
                return notes;
            case Event.COLUMN_ROUTE:
                return route.getName();
            case Event.COLUMN_TEMPERATURE:
                return new Integer(temperature);
            case Event.COLUMN_TYPE:
                return rowingType;
            case Event.COLUMN_WIND_DIRECTION:
                return I18n.getMsg("windDir." + Integer.toString(windDirection));
            case Event.COLUMN_WIND_SPEED:
                return I18n.getMsg("windSpeed." + Integer.toString(windSpeed));
            case Event.COLUMN_WEIGHT:
                return Utils.doubleToStr(Units.fromStdWeight(weight));
            case Event.COLUMN_CALORIES:
                return Utils.doubleToStr(calories);
            case Event.COLUMN_WATTAGE:
                return Utils.doubleToStr(wattage);
            default:
                return super.getColumnData(column);
        }
    }
    
    public double getWattage() {
        return wattage;
    }
    
    public void setWattage(double wattage) {
        this.wattage = wattage;
    }
    
    public double getWeight() {
        return weight;
    }
    
    public void setWeight(double weight) {
        this.weight = weight;
    }
    
    public double getCalories() {
        return calories;
    }
    
    public void setCalories(double calories) {
        this.calories = calories;
    }
}
