/*
 * RideWindow.java
 *
 * Created on 13  2003 ., 12:29
 */

package com.fn.BikersLog;


import java.text.NumberFormat;
import java.text.DateFormat;
import java.util.Date;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JOptionPane;


/**
 *
 * @author  asso
 */
public class RunningWindow extends javax.swing.JDialog {
    
    private Log log;
    private RunningEvent event;
    private boolean okPressed = false;
    private DateFormat dateFormat;
    
    /** Creates new form RideWindow */
    public RunningWindow(java.awt.Frame parent, Log log, RunningEvent re, boolean editing) {
        super(parent, true);
        if (editing)
            setTitle(I18n.getMsg("runningForm.editTitle"));
        else
            setTitle(I18n.getMsg("runningForm.newTitle"));
        this.log = log;
        event = re;
        dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        dateFormat.setLenient(false);
        initComponents();
        fillDicts();
        setValues();
        Utils.centerWindow(this, parent);
    }
    
    private void fillDicts() {
        String[] items = new String[4];
        for (int i = 0; i < items.length; i++)
            items[i] = I18n.getMsg("windDir." + Integer.toString(i + 1));
        windDirCombo.setModel(new DefaultComboBoxModel(items));
        
        items = new String[13];
        for (int i = 0; i < items.length; i++)
            items[i] = I18n.getMsg("windSpeed." + Integer.toString(i));
        windSpeedCombo.setModel(new DefaultComboBoxModel(items));
    }
    
    private void setValues() {
        RunRoute route = event.getRoute();
        if (null == route)
            routeCombo.setSelectedIndex(0);
        else
            if (route.isDeleted()) {
                ((ComboListAdapter)routeCombo.getModel()).setAddonItem(route);
                routeCombo.setSelectedIndex(0);
            } else
                routeCombo.setSelectedIndex(log.getRunRoutesList().getIndexOf(route));
        distanceTextField.setText(Utils.doubleToStr(Units.fromStdBDist(event.getDistance())));
        windDirCombo.setSelectedIndex(event.getWindDirection() - 1);
        windSpeedCombo.setSelectedIndex(event.getWindSpeed());
        startCalendar.setDate(event.getStart());
        startTime.setTime(event.getStart());
        finishCalendar.setDate(event.getFinish());
        finishTime.setTime(event.getFinish());
        elapsedTextField.setText(Utils.intervalToTime(event.getElapsed()));
        temperatureTextField.setText(Integer.toString(event.getTemperature()));
        speedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(event.getAvgSpeed())));
        maxSpeedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(event.getMaxSpeed())));
        hrTextField.setText(Integer.toString(event.getHeartRate()));
        notesTextArea.setText(event.getNotes());
        weightTextField.setText(Utils.doubleToStr(
                Units.fromStdWeight(event.getWeight())));
        caloriesTextField.setText(Utils.doubleToStr(event.getCalories()));
        wattageTextField.setText(Utils.doubleToStr(event.getWattage()));
    }
    
    private int getInterval(String text, String exceptionKey) throws Exception {
        int interval;
        try {
            interval = Utils.timetoInterval(text);
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
        if (interval < 0)
            throw new Exception(I18n.getMsg(exceptionKey));
        else
            return interval;
    }
    
    private void getValues() throws Exception {
        double distance = Units.toStdBDist(
                    Utils.parseDouble(distanceTextField.getText(), 
                    "rowForm.invalidDistance"));
        int elapsed = getInterval(elapsedTextField.getText(), "rowForm.invalidInterval");
        int temperature = Utils.parseInt(temperatureTextField.getText(), 
                "rowForm.invalidTemperature");
        double avgSpeed = Units.toStdSpeed(Utils.parseDouble(speedTextField.getText(), 
                    "rowForm.invalidSpeed"));
        double maxSpeed = Units.toStdSpeed(Utils.parseDouble(maxSpeedTextField.getText(), 
                    "rowForm.invalidMaxSpeed"));
        int heartRate = Utils.parseInt(hrTextField.getText(), "rowForm.invalidHR");
        double weight = Utils.parseDouble(weightTextField.getText(), 
                    "generic.invalidWeight");
        double calories = Utils.parseDouble(caloriesTextField.getText(), 
                    "rideForm.invalidCalories");
        double wattage = Utils.parseDouble(wattageTextField.getText(), 
                    "rideForm.invalidWattage");
        
        event.setRoute(log.getRunRoutesList().get(routeCombo.getSelectedIndex()));
        event.setDistance(distance);
        event.setWindDirection(windDirCombo.getSelectedIndex() + 1);
        event.setWindSpeed(windSpeedCombo.getSelectedIndex());
        event.setStart(Utils.calendarToDateTime(startCalendar, startTime));
        event.setFinish(Utils.calendarToDateTime(finishCalendar, finishTime));
        event.setElapsed(elapsed);
        event.setTemperature(temperature);
        event.setAvgSpeed(avgSpeed);
        event.setMaxSpeed(maxSpeed);
        event.setHeartRate(heartRate);
        event.setNotes(notesTextArea.getText());
        event.setWeight(Units.toStdWeight(weight));
        event.setCalories(calories);
        event.setWattage(wattage);
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        java.awt.GridBagConstraints gridBagConstraints;

        jPanel1 = new javax.swing.JPanel();
        okBtn = new javax.swing.JButton();
        cancelBtn = new javax.swing.JButton();
        jPanel6 = new javax.swing.JPanel();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jPanel2 = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        routeCombo = new javax.swing.JComboBox();
        editRouteBtn = new javax.swing.JButton();
        jLabel8 = new javax.swing.JLabel();
        startCalendar = new org.rapla.components.calendar.RaplaCalendar();
        startTime = new org.rapla.components.calendar.RaplaTime();
        jLabel12 = new javax.swing.JLabel();
        finishCalendar = new org.rapla.components.calendar.RaplaCalendar();
        finishTime = new org.rapla.components.calendar.RaplaTime();
        jLabel18 = new javax.swing.JLabel();
        elapsedTextField = new javax.swing.JTextField();
        calcElapsedTimeBtn = new javax.swing.JButton();
        jPanel3 = new javax.swing.JPanel();
        jLabel10 = new javax.swing.JLabel();
        windDirCombo = new javax.swing.JComboBox();
        jLabel11 = new javax.swing.JLabel();
        jLabel13 = new javax.swing.JLabel();
        temperatureTextField = new javax.swing.JTextField();
        windSpeedCombo = new javax.swing.JComboBox();
        jPanel4 = new javax.swing.JPanel();
        jLabel3 = new javax.swing.JLabel();
        distanceTextField = new javax.swing.JTextField();
        jLabel4 = new javax.swing.JLabel();
        speedTextField = new javax.swing.JTextField();
        jLabel9 = new javax.swing.JLabel();
        hrTextField = new javax.swing.JTextField();
        calcAvgSpeedBtn = new javax.swing.JButton();
        getDistanceBtn = new javax.swing.JButton();
        jLabel14 = new javax.swing.JLabel();
        maxSpeedTextField = new javax.swing.JTextField();
        jLabel15 = new javax.swing.JLabel();
        wattageTextField = new javax.swing.JTextField();
        jLabel16 = new javax.swing.JLabel();
        weightTextField = new javax.swing.JTextField();
        jLabel17 = new javax.swing.JLabel();
        caloriesTextField = new javax.swing.JTextField();
        jLabel2 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        jPanel7 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        notesTextArea = new javax.swing.JTextArea();

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });

        jPanel1.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.CENTER, 8, 8));

        okBtn.setText(I18n.getMsg("generic.ok"));
        okBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okBtnActionPerformed(evt);
            }
        });

        jPanel1.add(okBtn);

        cancelBtn.setText(I18n.getMsg("generic.cancel"));
        cancelBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelBtnActionPerformed(evt);
            }
        });

        jPanel1.add(cancelBtn);

        getContentPane().add(jPanel1, java.awt.BorderLayout.SOUTH);

        jPanel6.setLayout(new javax.swing.BoxLayout(jPanel6, javax.swing.BoxLayout.X_AXIS));

        jPanel6.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 0, 8)));
        jPanel2.setLayout(new java.awt.GridBagLayout());

        jPanel2.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel1.setLabelFor(routeCombo);
        jLabel1.setText(I18n.getMsg("rowingForm.rowing.route"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel2.add(jLabel1, gridBagConstraints);

        routeCombo.setModel(new ComboListAdapter(log.getRunRoutesList()));
        routeCombo.setPreferredSize(new java.awt.Dimension(220, 24));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel2.add(routeCombo, gridBagConstraints);

        editRouteBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/History16.gif")));
        editRouteBtn.setToolTipText(I18n.getMsg("rideForm.ride.viewRoute"));
        editRouteBtn.setAlignmentX(0.5F);
        editRouteBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        editRouteBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        editRouteBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                editRouteBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 4, 0);
        jPanel2.add(editRouteBtn, gridBagConstraints);

        jLabel8.setText(I18n.getMsg("rideForm.timing.start"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel8, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel2.add(startCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(startTime, gridBagConstraints);

        jLabel12.setText(I18n.getMsg("rideForm.timing.finish"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel2.add(jLabel12, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel2.add(finishCalendar, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel2.add(finishTime, gridBagConstraints);

        jLabel18.setLabelFor(elapsedTextField);
        jLabel18.setText(I18n.getMsg("rideForm.timing.elapsed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel2.add(jLabel18, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 2.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel2.add(elapsedTextField, gridBagConstraints);

        calcElapsedTimeBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcElapsedTimeBtn.setToolTipText(I18n.getMsg("rideForm.timing.calcLength"));
        calcElapsedTimeBtn.setAlignmentX(0.5F);
        calcElapsedTimeBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcElapsedTimeBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcElapsedTimeBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcElapsedTimeBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel2.add(calcElapsedTimeBtn, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("generic.propertiesTitle"), jPanel2);

        jPanel3.setLayout(new java.awt.GridBagLayout());

        jPanel3.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel10.setLabelFor(windDirCombo);
        jLabel10.setText(I18n.getMsg("rideForm.weather.windDir"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel3.add(jLabel10, gridBagConstraints);

        windDirCombo.setPreferredSize(new java.awt.Dimension(200, 24));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel3.add(windDirCombo, gridBagConstraints);

        jLabel11.setText(I18n.getMsg("rideForm.weather.windSpeed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel3.add(jLabel11, gridBagConstraints);

        jLabel13.setLabelFor(temperatureTextField);
        jLabel13.setText(I18n.getMsg("rideForm.weather.temperature"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel3.add(jLabel13, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel3.add(temperatureTextField, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel3.add(windSpeedCombo, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.weather"), jPanel3);

        jPanel4.setLayout(new java.awt.GridBagLayout());

        jPanel4.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel3.setLabelFor(distanceTextField);
        jLabel3.setText(I18n.getMsg("rideForm.results.distance"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 4);
        jPanel4.add(jLabel3, gridBagConstraints);

        distanceTextField.setPreferredSize(new java.awt.Dimension(150, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        jPanel4.add(distanceTextField, gridBagConstraints);

        jLabel4.setLabelFor(speedTextField);
        jLabel4.setText(I18n.getMsg("rideForm.results.speed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel4, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(speedTextField, gridBagConstraints);

        jLabel9.setLabelFor(hrTextField);
        jLabel9.setText(I18n.getMsg("rideForm.results.hr"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel9, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(hrTextField, gridBagConstraints);

        calcAvgSpeedBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        calcAvgSpeedBtn.setToolTipText(I18n.getMsg("rideForm.results.calcSpeed"));
        calcAvgSpeedBtn.setAlignmentX(0.5F);
        calcAvgSpeedBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        calcAvgSpeedBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        calcAvgSpeedBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                calcAvgSpeedBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(calcAvgSpeedBtn, gridBagConstraints);

        getDistanceBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Refresh16.gif")));
        getDistanceBtn.setToolTipText(I18n.getMsg("rideForm.results.getDistance"));
        getDistanceBtn.setAlignmentX(0.5F);
        getDistanceBtn.setMinimumSize(new java.awt.Dimension(18, 18));
        getDistanceBtn.setPreferredSize(new java.awt.Dimension(24, 24));
        getDistanceBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                getDistanceBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 0, 0);
        jPanel4.add(getDistanceBtn, gridBagConstraints);

        jLabel14.setText(I18n.getMsg("rideForm.results.maxSpeed"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel14, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(maxSpeedTextField, gridBagConstraints);

        jLabel15.setText(I18n.getMsg("rideForm.results.wattage"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel15, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(wattageTextField, gridBagConstraints);

        jLabel16.setText(I18n.getMsg("rideForm.results.weight"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        jPanel4.add(jLabel16, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        jPanel4.add(weightTextField, gridBagConstraints);

        jLabel17.setText(I18n.getMsg("rideForm.results.calories"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 0, 4);
        jPanel4.add(jLabel17, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 0, 0);
        jPanel4.add(caloriesTextField, gridBagConstraints);

        jLabel2.setText(Units.getBDist().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel2, gridBagConstraints);

        jLabel5.setText(Units.getSpeed().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel5, gridBagConstraints);

        jLabel6.setText(Units.getSpeed().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel6, gridBagConstraints);

        jLabel7.setText(Units.getWeight().getShortName());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 0);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel4.add(jLabel7, gridBagConstraints);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.results"), jPanel4);

        jPanel7.setLayout(new java.awt.BorderLayout());

        jPanel7.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jScrollPane1.setPreferredSize(new java.awt.Dimension(380, 200));
        notesTextArea.setLineWrap(true);
        notesTextArea.setWrapStyleWord(true);
        jScrollPane1.setViewportView(notesTextArea);

        jPanel7.add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jTabbedPane1.addTab(I18n.getMsg("rideForm.notes"), jPanel7);

        jPanel6.add(jTabbedPane1);

        getContentPane().add(jPanel6, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents

    private void calcElapsedTimeBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcElapsedTimeBtnActionPerformed
        Date start = Utils.calendarToDateTime(startCalendar, startTime);
        Date finish = Utils.calendarToDateTime(finishCalendar, finishTime);
        int interval = (int)((finish.getTime() - start.getTime()) / 1000);
        if (interval < 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidStartFinish"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        elapsedTextField.setText(Utils.intervalToTime(interval));
    }//GEN-LAST:event_calcElapsedTimeBtnActionPerformed

    private void editRouteBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_editRouteBtnActionPerformed
        RunRoute route = log.getRunRoutesList().get(routeCombo.getSelectedIndex());
        RunRouteWindow.edit(this, route);
    }//GEN-LAST:event_editRouteBtnActionPerformed

    private void getDistanceBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_getDistanceBtnActionPerformed
        RunRoute route = log.getRunRoutesList().get(routeCombo.getSelectedIndex());
        if (null != route)
            distanceTextField.setText(Utils.doubleToStr(Units.fromStdBDist(route.getLength())));
    }//GEN-LAST:event_getDistanceBtnActionPerformed

    private void calcAvgSpeedBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_calcAvgSpeedBtnActionPerformed
        double interval = Utils.timetoInterval(elapsedTextField.getText()) / 3600.0;
        if (interval <= 0) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidInterval"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        double distance;
        try {
            distance = Units.toStdBDist(NumberFormat.
                    getInstance().parse(distanceTextField.getText()).doubleValue());
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, I18n.getMsg("rideForm.invalidDistance"),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        speedTextField.setText(Utils.doubleToStr(Units.fromStdSpeed(distance / interval)));
    }//GEN-LAST:event_calcAvgSpeedBtnActionPerformed

    private void okBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okBtnActionPerformed
        try {
            getValues();
        } catch (Exception e) {
            JOptionPane.showMessageDialog(this, e.getMessage(),
                    I18n.getMsg("mainWindow.title"), JOptionPane.ERROR_MESSAGE);
            return;
        }
        okPressed = true;
        setVisible(false);
    }//GEN-LAST:event_okBtnActionPerformed

    private void cancelBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelBtnActionPerformed
        okPressed = false;
        setVisible(false);
    }//GEN-LAST:event_cancelBtnActionPerformed
    
    /** Closes the dialog */
    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        setVisible(false);
    }//GEN-LAST:event_closeDialog
    
    public static RunningEvent add(java.awt.Frame owner, Log log, Date start) {
        RunningEvent event = new RunningEvent();
        event.setStart(start);
        event.setFinish(start);
        RunningWindow rw = new RunningWindow(owner, log, event, false);
        rw.setVisible(true);
        rw.dispose();
        return rw.okPressed ? event : null;
    }
    
    public static boolean edit(java.awt.Frame owner, RunningEvent event, Log log) {
        RunningWindow rw = new RunningWindow(owner, log, event, true);
        rw.setVisible(true);
        rw.dispose();
        return rw.okPressed;
    }
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton calcAvgSpeedBtn;
    private javax.swing.JButton calcElapsedTimeBtn;
    private javax.swing.JTextField caloriesTextField;
    private javax.swing.JButton cancelBtn;
    private javax.swing.JTextField distanceTextField;
    private javax.swing.JButton editRouteBtn;
    private javax.swing.JTextField elapsedTextField;
    private org.rapla.components.calendar.RaplaCalendar finishCalendar;
    private org.rapla.components.calendar.RaplaTime finishTime;
    private javax.swing.JButton getDistanceBtn;
    private javax.swing.JTextField hrTextField;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JTextField maxSpeedTextField;
    private javax.swing.JTextArea notesTextArea;
    private javax.swing.JButton okBtn;
    private javax.swing.JComboBox routeCombo;
    private javax.swing.JTextField speedTextField;
    private org.rapla.components.calendar.RaplaCalendar startCalendar;
    private org.rapla.components.calendar.RaplaTime startTime;
    private javax.swing.JTextField temperatureTextField;
    private javax.swing.JTextField wattageTextField;
    private javax.swing.JTextField weightTextField;
    private javax.swing.JComboBox windDirCombo;
    private javax.swing.JComboBox windSpeedCombo;
    // End of variables declaration//GEN-END:variables
    
}
