/*
 * TrainEvent.java
 *
 * Created on 12  2003 ., 21:49
 */

package com.fn.BikersLog;


import java.text.DateFormat;
import java.util.Date;
import javax.swing.ImageIcon;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;


/**
 *
 * @author  asso
 */
public class SwimmingEvent extends Event {
    
    private double distance;
    private Date finish = new Date();
    private int elapsed;
    private double avgSpeed;
    private int heartRate;
    private String notes;
    private static String swimmingType = I18n.getMsg("swimming.type");
    private static ImageIcon icon = null;
    private double weight;
    private double calories;
    private int style = 1;
    
    /** Creates a new instance of TrainEvent */
    public SwimmingEvent() {
    }
    
    public SwimmingEvent(Element row, Log log) {
        distance = DOMUtil.getSubtagData(row, "distance", 0.0);
        setStart(DOMUtil.getSubtagData(row, "start", new Date()));
        finish = DOMUtil.getSubtagData(row, "finish", new Date());
        elapsed = DOMUtil.getSubtagData(row, "elapsed", 0);
        avgSpeed = DOMUtil.getSubtagData(row, "avgSpeed", 0.0);
        heartRate = DOMUtil.getSubtagData(row, "heartRate", 0);
        notes = DOMUtil.getSubtagData(row, "notes", "");
        weight = DOMUtil.getSubtagData(row, "weight", 0.0);
        calories = DOMUtil.getSubtagData(row, "calories", 0.0);
        style = DOMUtil.getSubtagData(row, "style", 1);
    }
    
    public double getDistance() {
        return distance;
    }
    
    public void setDistance(double distance) {
        this.distance = distance;
    }
    
    public java.util.Date getFinish() {
        return finish;
    }
    
    public void setFinish(java.util.Date finish) {
        this.finish = finish;
    }
    
    public int getElapsed() {
        return elapsed;
    }
    
    public void setElapsed(int elapsed) {
        this.elapsed = elapsed;
    }
    
    public double getAvgSpeed() {
        return avgSpeed;
    }
    
    public void setAvgSpeed(double avgSpeed) {
        this.avgSpeed = avgSpeed;
    }
    
    public int getHeartRate() {
        return heartRate;
    }
    
    public void setHeartRate(int heartRate) {
        this.heartRate = heartRate;
    }
    
    public java.lang.String getNotes() {
        return notes;
    }
    
    public void setNotes(java.lang.String notes) {
        this.notes = notes;
    }
    
    public String toString() {
        DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        StringBuffer sb = new StringBuffer();
        sb.append(df.format(getStart())).append(' ').append(swimmingType);
        sb.append(' ').append(Utils.intervalToTime(elapsed)).append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdBDist(distance)));
        sb.append(Units.getBDist().getShortName());
        sb.append(", ");
        sb.append(Utils.doubleToStr(Units.fromStdSpeed(avgSpeed)));
        sb.append(Units.getSpeed().getShortName());
        return sb.toString();
    }
    
    public void save(Document document, Element root) {
        Element ride = DOMUtil.addElement(document, root, "event");
        DOMUtil.addDataElement(document, ride, "type", "swimming");
        DOMUtil.addDataElement(document, ride, "start", getStart());
        DOMUtil.addDataElement(document, ride, "finish", finish);
        DOMUtil.addDataElement(document, ride, "distance", distance);
        DOMUtil.addDataElement(document, ride, "elapsed", elapsed);
        DOMUtil.addDataElement(document, ride, "avgSpeed", avgSpeed);
        DOMUtil.addDataElement(document, ride, "heartRate", heartRate);
        DOMUtil.addDataElement(document, ride, "notes", notes);
        DOMUtil.addDataElement(document, ride, "weight", weight);
        DOMUtil.addDataElement(document, ride, "calories", calories);
        DOMUtil.addDataElement(document, ride, "style", style);
    }    
    
    public void onRemove() {
    }
    
    public ImageIcon getIcon() {
        if (null == icon)
            icon = new ImageIcon(getClass().getResource("/com/fn/BikersLog/img/swimming.png"));
        return icon;
    }
    
    public Object getColumnData(int column) {
        switch (column) {
            case Event.COLUMN_AVG_SPEED:
                return Utils.doubleToStr(Units.fromStdSpeed(avgSpeed));
            case Event.COLUMN_DISTANCE:
                return Utils.doubleToStr(Units.fromStdBDist(distance));
            case Event.COLUMN_ELAPSED:
                return Utils.intervalToTime(elapsed);
            case Event.COLUMN_FINISH:
                return finish;
            case Event.COLUMN_HEART_RATE:
                return new Integer(heartRate);
            case Event.COLUMN_NOTES:
                return notes;
            case Event.COLUMN_TYPE:
                return swimmingType;
            case Event.COLUMN_WEIGHT:
                return Utils.doubleToStr(Units.fromStdWeight(weight));
            case Event.COLUMN_CALORIES:
                return Utils.doubleToStr(calories);
            case Event.COLUMN_STYLE:
                return getStyleName(style);
            default:
                return super.getColumnData(column);
        }
    }
    
    public double getWeight() {
        return weight;
    }
    
    public void setWeight(double weight) {
        this.weight = weight;
    }
    
    public double getCalories() {
        return calories;
    }
    
    public void setCalories(double calories) {
        this.calories = calories;
    }
    
    public int getStyle() {
        return style;
    }
    
    public void setStyle(int style) {
        this.style = style;
    }
    
    public static String getStyleName(int style) {
        return I18n.getMsg("swimmingStyle." + Integer.toString(style - 1));
    }
}
