/*
 * TableEventsView.java
 *
 * Created on 6  2004 ., 9:45
 */

package com.fn.BikersLog;


import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Set;
import javax.swing.table.TableColumn;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.JScrollPane;
import javax.swing.JTable;


/**
 *
 * @author  asso
 */
public class TableEventsView extends EventsView 
    implements Config.TableOptionsListener {
    
    private JTable table;
    private Container parent;
    private JScrollPane scrollPane;
    private JPopupMenu headerPopup;
    private EventsTableModel tableModel;
    
    /** Creates a new instance of TableEventsView */
    public TableEventsView(Log log) {
        super(log);
        tableModel = new EventsTableModel(log.getEventsList());
        table = new JTable(tableModel);
        table.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        scrollPane = new JScrollPane(table);
        if (Config.getTableShowScroll())
            table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        else
            table.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
        createHeaderPopup();
        table.getTableHeader().addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent e) {
                if (e.BUTTON3 == e.getButton())
                    headerPopup.show(table.getTableHeader(), e.getX(), e.getY());
            }
        });
        table.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent e) {
                if ((e.BUTTON1 == e.getButton()) && (e.getClickCount() == 2))
                    MainWindow.getInstance().editEvent();
            }
        });
        if (tableModel.getRowCount() > 0)
            table.changeSelection(0, 0, false, false);
        tableModel.startMonitoring();
    }
    
    private void setColumnsWidth() {
        int[] widths = Config.getTableColWidths();
        int[] indexes = Config.getTableColIndexes();
        
        int cnt = table.getColumnCount();
        for (int i = 0; i < cnt; i++) {
            int modelIdx = i;
            if ((null != indexes) && (i < indexes.length))
                modelIdx = indexes[i];
            int viewIdx = table.convertColumnIndexToView(modelIdx);
            table.moveColumn(viewIdx, i);
            TableColumn col = table.getColumnModel().getColumn(i);
            int w = col.getWidth();
            if ((null != widths) && (i < widths.length))
                w = widths[i];
            col.setPreferredWidth(w);
        }
    }
    
    private void saveColumnsWidth() {
        int cnt = table.getColumnCount();
        int[] widths = new int[cnt];
        int[] indexes = new int[cnt];
        for (int i = 0; i < cnt; i++) {
            TableColumn col = table.getColumnModel().getColumn(i);
            widths[i] = col.getWidth();
            indexes[i] = col.getModelIndex();
        }
        Config.setTableColIndexes(indexes);
        Config.setTableColWidths(widths);
    }
    
    private class ColumnsActionListener implements ActionListener {
        
        private Integer itemNo;
        private JCheckBoxMenuItem menuItem;
        
        public ColumnsActionListener(Integer no, JCheckBoxMenuItem item) {
            itemNo = no;
            menuItem = item;
        }
        
        public void actionPerformed(ActionEvent e) {
            boolean enabled = menuItem.isSelected();
            Set columns = Config.getGridColumns();
            if ((! enabled) && (1 == columns.size()))
                menuItem.setSelected(true);
            else
                if (columns.contains(itemNo))
                    columns.remove(itemNo);
                else
                    columns.add(itemNo);
            tableModel.updateColumns();
            saveColumnsWidth();
        }
        
    }
    
    private void createHeaderPopup() {
        headerPopup = new JPopupMenu();
        int cnt = Event.getColumnsCount();
        java.util.Set columns = Config.getGridColumns();
        for (int i = 0; i < cnt; i++) {
            Integer itemNo = new Integer(i);
            JCheckBoxMenuItem item = new JCheckBoxMenuItem(Event.getColumnName(i),
                columns.contains(itemNo));
            item.addActionListener(new ColumnsActionListener(itemNo, item));
            headerPopup.add(item);
        }
    }
    
    public void install(Container parent) {
        this.parent = parent;
        parent.add(scrollPane);
        Config.setTableOptionsListener(this);
        setColumnsWidth();
        scrollPane.setVisible(true);
        table.requestFocus();
    }
    
    public void remove() {
        saveColumnsWidth();
        parent.remove(scrollPane);
        Config.setTableOptionsListener(null);
        tableModel.stopMonitoring();
    }
    
    public void setLog(Log log) {
        this.log = log;
        tableModel.stopMonitoring();
        tableModel = new EventsTableModel(log.getEventsList());
        table.setModel(tableModel);
        setColumnsWidth();
        tableModel.startMonitoring();
        if (tableModel.getRowCount() > 0)
            table.changeSelection(0, 0, false, false);
        table.requestFocus();
    }
    
    public void saveOptions() {
        saveColumnsWidth();
    }
    
    public void onOptionsChanged() {
        tableModel.updateDateFormat();
        int newMode = Config.getTableShowScroll() ? 
                JTable.AUTO_RESIZE_OFF : JTable.AUTO_RESIZE_ALL_COLUMNS;
        if (newMode != table.getAutoResizeMode())
            table.setAutoResizeMode(newMode);
        else
            tableModel.fireTableDataChanged();
    }
    
    public Event getSelected(boolean edit) {
        int idx = table.getSelectedRow();
        if (idx < 0)
            return null;
        else
            return log.getEventsList().get(idx);
    }
    
    public void setSelectedIndex(int index) {
        table.getSelectionModel().clearSelection();
        table.getSelectionModel().setSelectionInterval(index, index);
    }
    
}
