/*
 * Utils.java
 *
 * Created on 27  2002 ., 12:53
 */

package com.fn.BikersLog;


import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.text.DateFormat;
import java.text.NumberFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.StringTokenizer;
import javax.swing.ComboBoxModel;
import javax.swing.DefaultComboBoxModel;
import org.rapla.components.calendar.RaplaCalendar;
import org.rapla.components.calendar.RaplaTime;


/**
 *
 * @author  asso
 */
public class Utils {

    private static final int COPY_BUFFER_SIZE = 10240;
    
    public static void centerWindow(java.awt.Window window) {
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        java.awt.Dimension windowSize = window.getSize();
        int x = (int)((screenSize.getWidth() - windowSize.getWidth()) / 2);
        int y = (int)((screenSize.getHeight() - windowSize.getHeight()) / 2);
        window.setLocation(x, y);
    }

    /**
     * Center window relative owner
     * @param window window to center
     * @param owner window owner
     */    
    public static void centerWindow(java.awt.Window window, java.awt.Window owner) {
        java.awt.Rectangle rect = owner.getBounds();
        java.awt.Dimension windowSize = window.getSize();
        int x = (int)(rect.x + (rect.getWidth() - windowSize.getWidth()) / 2);
        int y = (int)(rect.y + (rect.getHeight() - windowSize.getHeight()) / 2);
        window.setLocation(x, y);
    }

    private static String intToStr2(int v) {
        String s = Integer.toString(v);
        if (s.length() < 2)
            return "0" + s;
        else
            return s;
    }
    
    public static String intervalToTime(int seconds) {
        int h = seconds / 3600;
        seconds = seconds - h * 3600;
        int m = seconds / 60;
        seconds = seconds - m * 60;
        return intToStr2(h) + ":" + intToStr2(m) /*+ ":" + intToStr2(seconds)*/;
    }
    
    public static int timetoInterval(String time) {
        String[] tokens = new String[2];
        StringTokenizer st = new StringTokenizer(time, ":");
        int i = 0;
        while (st.hasMoreTokens()) {
            if (i > 1) return -1;
            tokens[i] = st.nextToken();
            i++;
        }
        if (i != 2) return -1;
        try {
            return Integer.parseInt(tokens[0]) * 3600 + 
                Integer.parseInt(tokens[1]) * 60 /*+ Integer.parseInt(tokens[2])*/;
        } catch (Exception e) {
            return -1;
        }
    }
    
    private static InputStream getResourceStream(String name) {
        Class c = Utils.class;
        return c.getResourceAsStream(name);
    }
    
    public static InputStream getIntlResource(String name) throws Exception {
        Locale locale = Locale.getDefault();
        int dotPos = name.lastIndexOf('.');
        if ((dotPos <= 0) || (dotPos >= name.length() -1))
            throw new Exception("Invalid resource extension");
        String fileName = name.substring(0, dotPos);
        String fileExt = name.substring(dotPos + 1);
        InputStream is;
        is = getResourceStream(fileName + "_" + locale.getLanguage() + "_" +
                    locale.getCountry() + "." + fileExt);
        if (is != null) return is;
        is = getResourceStream(fileName + "_" + locale.getLanguage() + "." + fileExt);
        if (is != null) return is;
        is = getResourceStream(fileName + "." + fileExt);
        if (is != null) return is;
        throw new Exception("Resource not found");
    }
    
    public static String formatDate(Date date) {
        DateFormat df = DateFormat.getDateInstance(DateFormat.SHORT);
        return df.format(date);        
    }
    
    public static String formatDateTime(Date date) {
        DateFormat df = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
        return df.format(date);        
    }
    
    public static Date calendarToDateTime(RaplaCalendar calendar, RaplaTime time) {
        Calendar cal = Calendar.getInstance();
        Calendar dateCal = Calendar.getInstance();
        cal.setTime(time.getTime());
        dateCal.setTime(calendar.getDate());
        dateCal.set(Calendar.HOUR_OF_DAY, cal.get(Calendar.HOUR_OF_DAY));
        dateCal.set(Calendar.MINUTE, cal.get(Calendar.MINUTE));
        dateCal.set(Calendar.SECOND, cal.get(Calendar.SECOND));
        return dateCal.getTime();
    }
    
    public static Date subMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.roll(Calendar.MONTH, false);
        return calendar.getTime();
    }
    
    public static String doubleToStr(double value) {
        return doubleToStr(value, 1, 1);
    }
    
    public static String doubleToStr(double value, int minFract, int maxFract) {
        NumberFormat nf = NumberFormat.getInstance();
        nf.setMaximumFractionDigits(minFract);
        nf.setMinimumFractionDigits(maxFract);
        return nf.format(value);
    }
    
    public static double parseDouble(String text, String exceptionKey) throws Exception {
        try {
            return NumberFormat.getInstance().parse(text).doubleValue();
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
    }
    
    public static int parseInt(String text, String exceptionKey) throws Exception {
        try {
            return Integer.parseInt(text);
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
    }
    
    public static Date parseDate(String text, String exceptionKey, 
            DateFormat dateFormat) throws Exception 
    {
        Date date;
        try {
            date = dateFormat.parse(text);
        } catch (Exception e) {
            throw new Exception(I18n.getMsg(exceptionKey));
        }
        if (date == null)
            throw new Exception(I18n.getMsg(exceptionKey));
        else
            return date;
    }
    
    public static String getExtension(java.io.File f) {
        String ext = null;
        String s = f.getName();
        int i = s.lastIndexOf('.');
        if (i > 0 &&  i < s.length() - 1)
            ext = s.substring(i+1).toLowerCase();
        return ext;
    }
 
    public static java.awt.Dialog findParentDialog(java.awt.Component c) {
        while ((null != c) && (! (c instanceof java.awt.Dialog)))
            c = c.getParent();
        return (java.awt.Dialog)c;
    }
    
    public static void saveBackupFile(File file) {
        if (! file.exists())
            return;
        String fileName = file.getName();
        if ((null == fileName) || (0 == fileName.length()))
            return;
        int idx = fileName.lastIndexOf('.');
        File backupFile;
        if (0 >= idx)
            backupFile = new File(file.getParent(), fileName + ".bak");
        else
            backupFile = new File(file.getParent(), fileName.substring(0, idx) 
                + ".bak");
        try {
            InputStream is = new BufferedInputStream(new FileInputStream(file));
            OutputStream os = new BufferedOutputStream(new FileOutputStream(
                    backupFile));
            byte[] buffer = new byte[COPY_BUFFER_SIZE];
            int cnt;
            while (((cnt = is.read(buffer)) != -1)) {
                if (cnt > 0)
                    os.write(buffer, 0, cnt);
            }
            is.close();
            os.close();
        } catch (Exception e) {
            System.out.println("Can't save backup file: " + e.getMessage());
        }
    }
    
    public static ComboBoxModel createPropEnumComboModel(String propName) {
        ResourceBundle bundle = ResourceBundle.getBundle("com/fn/BikersLog/messages");
        DefaultComboBoxModel dcm = new DefaultComboBoxModel();
        for (int i = 0; ; i++) {
            try {
                String s = bundle.getString(propName + "." + Integer.toString(i));
                dcm.addElement(s);
            } catch (Exception e) {
                if (0 != i)
                    break;
            }
        }
        return dcm;
    }
}
