/*
 * MonthViewPane.java
 *
 * Created on 11  2004 ., 11:49
 */

package com.fn.BikersLog.prefs;


import java.awt.Component;
import java.awt.Font;
import java.util.Set;
import java.util.TreeSet;
import javax.swing.DefaultListModel;
import javax.swing.JCheckBox;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import com.fn.BikersLog.Config;
import com.fn.BikersLog.Event;
import com.fn.BikersLog.FontChooserDialog;
import com.fn.BikersLog.I18n;
import com.fn.BikersLog.Utils;


/**
 *
 * @author  asso
 */
public class MonthViewPane extends javax.swing.JPanel implements PreferencesPage {
    
    private Font calTitleFont;
    private Font calDataFont;
    private DefaultListModel columnsListModel;
    private int checkBoxWidth;
    
    /** Creates new form MonthViewPane */
    public MonthViewPane() {
        checkBoxWidth = (int)(new JCheckBox().getPreferredSize().getWidth());
        if (checkBoxWidth < 10)
            checkBoxWidth = 21;
        calTitleFont = Config.getCalendarTitleFont();
        calDataFont = Config.getCalendarDataFont();
        columnsListModel = new DefaultListModel();
        initColumns();
        initComponents();
    }
    
    private String fontToStr(Font font) {
        String family = font.getFamily();
        String size = Integer.toString(font.getSize());
        String styleName;
        int style = font.getStyle();
        switch (style) {
            case Font.PLAIN: styleName = "plain"; break;
            case Font.BOLD: styleName = "bold"; break;
            case Font.ITALIC: styleName = "italic"; break;
            default: styleName = "bolditalic";
        }
        return family + "-" + styleName + "-" + size;
    }
    
    private class Column {
        private String name;
        private boolean visible;
        private int index;
        
        public Column(String name, boolean visible, int index) {
            this.name = name;
            this.visible = visible;
            this.index = index;
        }
        
        public String getName() {
            return name;
        }
        
        public boolean isVisible() {
            return visible;
        }
        
        public void setVisible(boolean v) {
            visible = v;
        }
        
        public int getIndex() {
            return index;
        }
    }
    
    private class ColumnRenderer extends JCheckBox implements ListCellRenderer {
        
        public Component getListCellRendererComponent(JList list, Object value, 
                int index, boolean isSelected, boolean cellHasFocus) 
        {
            Column c = (Column)value;
            setText(c.getName());
            setSelected(c.isVisible());
            if (isSelected) {
                setBackground(list.getSelectionBackground());
                setForeground(list.getSelectionForeground());
            } else {
                setBackground(list.getBackground());
                setForeground(list.getForeground());
            }
            setEnabled(list.isEnabled());
            setFont(list.getFont());
            setOpaque(isSelected);
            return this;
        }
        
    }
    
    private void initColumns() {
        int cnt = Event.getColumnsCount();
        Set used = new TreeSet();
        int[] columns = Config.getCalendarColumns();
        if ((null != columns) && (columns.length > 0)) {
            int len = columns.length;
            for (int i = 0; i < len; i++) {
                int idx = columns[i];
                if ((idx >=0) && (idx < cnt)) {
                    Integer no = new Integer(idx);
                    if (! used.contains(no)) {
                        columnsListModel.addElement(new Column(
                            Event.getColumnName(idx), true, idx));
                        used.add(no);
                    }
                }
            }
        }
        for (int i = 0; i < cnt; i++)
            if (! used.contains(new Integer(i)))
                columnsListModel.addElement(new Column(Event.getColumnName(i), 
                        false, i));
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        java.awt.GridBagConstraints gridBagConstraints;

        jPanel7 = new javax.swing.JPanel();
        jLabel4 = new javax.swing.JLabel();
        titleFontField = new javax.swing.JTextField();
        titleFontBtn = new javax.swing.JButton();
        jLabel5 = new javax.swing.JLabel();
        dataFontField = new javax.swing.JTextField();
        dataFontBtn = new javax.swing.JButton();
        jPanel8 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        calColumnsList = new JList(columnsListModel);
        jPanel9 = new javax.swing.JPanel();
        colUpBtn = new javax.swing.JButton();
        colDownBtn = new javax.swing.JButton();
        jLabel6 = new javax.swing.JLabel();

        setLayout(new java.awt.BorderLayout());

        jPanel7.setLayout(new java.awt.GridBagLayout());

        jPanel7.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(8, 8, 8, 8)));
        jLabel4.setText(I18n.getMsg("preferencesForm.monthView.titleFont"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 4, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel7.add(jLabel4, gridBagConstraints);

        titleFontField.setEditable(false);
        titleFontField.setText(fontToStr(calTitleFont));
        titleFontField.setMinimumSize(new java.awt.Dimension(80, 19));
        titleFontField.setPreferredSize(new java.awt.Dimension(120, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        gridBagConstraints.weightx = 1.0;
        jPanel7.add(titleFontField, gridBagConstraints);

        titleFontBtn.setText(I18n.getMsg("generic.select"));
        titleFontBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                titleFontBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
        jPanel7.add(titleFontBtn, gridBagConstraints);

        jLabel5.setText(I18n.getMsg("preferencesForm.monthView.tableFont"));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 0, 8, 4);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        jPanel7.add(jLabel5, gridBagConstraints);

        dataFontField.setEditable(false);
        dataFontField.setText(fontToStr(calDataFont));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 8, 4);
        jPanel7.add(dataFontField, gridBagConstraints);

        dataFontBtn.setText(I18n.getMsg("generic.select"));
        dataFontBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                dataFontBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(4, 4, 8, 4);
        jPanel7.add(dataFontBtn, gridBagConstraints);

        jPanel8.setLayout(new java.awt.BorderLayout());

        calColumnsList.setCellRenderer(new ColumnRenderer());
        calColumnsList.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                calColumnsListMouseClicked(evt);
            }
        });

        jScrollPane1.setViewportView(calColumnsList);

        jPanel8.add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jPanel9.setLayout(new java.awt.GridBagLayout());

        colUpBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Up16.gif")));
        colUpBtn.setToolTipText(I18n.getMsg("preferencesForm.monthView.up"));
        colUpBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                colUpBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(0, 8, 4, 0);
        jPanel9.add(colUpBtn, gridBagConstraints);

        colDownBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/com/fn/BikersLog/img/Down16.gif")));
        colDownBtn.setToolTipText(I18n.getMsg("preferencesForm.monthView.down"));
        colDownBtn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                colDownBtnActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(4, 8, 0, 0);
        jPanel9.add(colDownBtn, gridBagConstraints);

        jPanel8.add(jPanel9, java.awt.BorderLayout.EAST);

        jLabel6.setText(I18n.getMsg("preferencesForm.monthView.columns"));
        jPanel8.add(jLabel6, java.awt.BorderLayout.NORTH);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(8, 0, 0, 0);
        gridBagConstraints.weighty = 10.0;
        jPanel7.add(jPanel8, gridBagConstraints);

        add(jPanel7, java.awt.BorderLayout.CENTER);

    }//GEN-END:initComponents

    private void colDownBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_colDownBtnActionPerformed
        int idx = calColumnsList.getSelectedIndex();
        if ((idx < 0) || (idx >= columnsListModel.size() - 1))
            return;
        Column c1 = (Column)columnsListModel.get(idx);
        Column c2 = (Column)columnsListModel.get(idx + 1);
        columnsListModel.setElementAt(c2, idx);
        columnsListModel.setElementAt(c1, idx + 1);
        calColumnsList.setSelectedIndex(idx + 1);
        calColumnsList.ensureIndexIsVisible(idx + 1);
    }//GEN-LAST:event_colDownBtnActionPerformed

    private void colUpBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_colUpBtnActionPerformed
        int idx = calColumnsList.getSelectedIndex();
        if (idx <= 0)
            return;
        Column c1 = (Column)columnsListModel.get(idx);
        Column c2 = (Column)columnsListModel.get(idx - 1);
        columnsListModel.setElementAt(c2, idx);
        columnsListModel.setElementAt(c1, idx - 1);
        calColumnsList.setSelectedIndex(idx - 1);
        calColumnsList.ensureIndexIsVisible(idx - 1);
    }//GEN-LAST:event_colUpBtnActionPerformed

    private void calColumnsListMouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_calColumnsListMouseClicked
        if (evt.getX() < checkBoxWidth) {
            int idx = calColumnsList.locationToIndex(evt.getPoint());
            if (idx >= 0) {
                Column c = (Column)columnsListModel.get(idx);
                c.setVisible(! c.isVisible());
                columnsListModel.setElementAt(c, idx);
            }
        }
    }//GEN-LAST:event_calColumnsListMouseClicked

    private void dataFontBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_dataFontBtnActionPerformed
        Font newFont = FontChooserDialog.chooseFont(Utils.findParentDialog(this),
            calDataFont);
        if (newFont != null) {
            calDataFont = newFont;
            dataFontField.setText(fontToStr(calDataFont));
        }
    }//GEN-LAST:event_dataFontBtnActionPerformed

    private void titleFontBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_titleFontBtnActionPerformed
        Font newFont = FontChooserDialog.chooseFont(Utils.findParentDialog(this), 
            calTitleFont);
        if (newFont != null) {
            calTitleFont = newFont;
            titleFontField.setText(fontToStr(calTitleFont));
        }
    }//GEN-LAST:event_titleFontBtnActionPerformed

    private void saveCalColumns() {
        int size = columnsListModel.size();
        
        // calculate quantity of visible columns
        int cnt = 0;
        for (int i = 0; i < size; i++)
            if (((Column)columnsListModel.get(i)).isVisible())
                cnt++;
        
        int arr[];
        if (0 == cnt) {
            // if no visible columns set one column visible
            arr = new int[1];
            arr[0] = Event.COLUMN_TYPE;
        } else {
            // create array and fill it with visible columns indeces
            arr = new int[cnt];
            int j = 0;
            for (int i = 0; i < size; i++) {
                Column c = (Column)columnsListModel.get(i);
                if (c.isVisible()) {
                    arr[j] = c.getIndex();
                    j++;
                }
            }
        }
        Config.setCalendarColumns(arr);
    }
    
    public void apply() {
        Config.setCalendarDataFont(calDataFont);
        Config.setCalendarTitleFont(calTitleFont);
        saveCalColumns();
    }    
    
    public void install(javax.swing.JPanel parent) {
        parent.add(this, java.awt.BorderLayout.CENTER);
    }    
    
    public void remove(javax.swing.JPanel parent) {
        parent.remove(this);
    }
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JList calColumnsList;
    private javax.swing.JButton colDownBtn;
    private javax.swing.JButton colUpBtn;
    private javax.swing.JButton dataFontBtn;
    private javax.swing.JTextField dataFontField;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JPanel jPanel8;
    private javax.swing.JPanel jPanel9;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JButton titleFontBtn;
    private javax.swing.JTextField titleFontField;
    // End of variables declaration//GEN-END:variables
    
}
